window.Gleam.initSearch([{"doc":"gtempo","title":"gtempo","content":"# Tempo\n\nA lightweight and Gleamy datetime library!\n\nOnly run a task past a certain time of day, calculate the difference beteen times and dates, time long running tasks, parse and format datetimes, and more! Over 400 unit tests, contributions welcome!\n\nWritten in almost pure Gleam, Tempo tries to optimize for the same thing the Gleam language does: explicitness over terseness and simplicity over convenience. My hope is to make Tempo feel like the Gleam language and to make it as difficult to write time related bugs as possible!\n\nSupports both the Erlang and JavaScript targets.\n\n## Installation\n\n```sh\ngleam add gtempo@6\n```\n\nSupports timezones only through the `gtz` package. Add it with:\n\n```sh\ngleam add gtz@1\n```\n\n[![Package Version](https://img.shields.io/hexpm/v/tempo)](https://hex.pm/packages/gtempo)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gtempo/)\n\n#### Parsing and Formatting\n\n```gleam\nimport tempo\nimport tempo/datetime\n\npub fn main() {\n  tempo.parse_any(&quot;Dec 25, 2024 at 1:00 PM&quot;)\n  // -&gt; Ok(#(Some(date), Some(time), None))\n\n  tempo.format_local(tempo.ISO8601Milli)\n  // -&gt; &quot;2024-12-25T06:04:20.534-04:00&quot;\n\n  datetime.literal(&quot;2024-12-25T06:00:00Z&quot;)\n  |&gt; datetime.format(tempo.Custom(&quot;ddd @ h:mm A&quot;))\n  // -&gt; &quot;Fri @ 6:00 AM&quot;\n\n  date.parse(&quot;03/02/1998&quot;, tempo.CustomDate(&quot;DD/MM/YYYY&quot;))\n  // -&gt; Ok(date.literal(&quot;1998-02-03&quot;))\n}\n```\n\n#### Time Zone Conversion\n\nTime zone conversion is only supported with an external package like `gtz` to provide timezone information.\n\n```gleam\nimport gtz\nimport tempo/datetime\n\npub fn main() {\n  let assert Ok(local_tz) = gtz.local_name() |&gt; gtz.timezone\n\n  datetime.from_unix_seconds(1_729_257_776)\n  |&gt; datetime.to_timezone(local_tz)\n  |&gt; datetime.to_string\n  // -&gt; &quot;2024-10-18T14:22:56.000+01:00&quot;\n\n  let assert Ok(tz) = gtz.timezone(&quot;America/New_York&quot;)\n\n  datetime.literal(&quot;2024-01-03T05:30:02.334Z&quot;)\n  |&gt; datetime.to_timezone(tz)\n  |&gt; datetime.to_string\n  // -&gt; &quot;2024-01-03T00:30:02.334-05:00&quot;\n}\n```\n\n#### Handling Current System Time\n\nTo aviod common pitfalls, the current system time is only returned as a `Instant` type. It is a monotonic type that represents a unique point in time on the host system and is the most complete representation of system time. It can be converted to all other time types if needed, but it should be used as in when possible.\n\nThe current system time can also be dealt with by using the `tempo` module functions like below.\n\n```gleam\nimport gleam/io\nimport tempo\nimport tempo/duration\nimport tempo/time\nimport tempo/instant\n\npub fn main() {\n  // Timing tasks\n  let timer = instant.now()\n  long_running_task()\n  instant.since(timer)\n  // -&gt; duration.minutes(42)\n\n  // Formatting the current system time\n  tempo.format_utc(tempo.ISO8601Seconds)\n  // -&gt; &quot;2024-12-26T15:04:20Z&quot;\n\n  // Comparing the system time to other times\n  let target = datetime.literal(&quot;2024-12-26T03:10:00Z&quot;)\n\n  case tempo.is_later(than: target) {\n    True -&gt;\n      io.println(\n        &quot;We are late by &quot;\n        &lt;&gt; tempo.difference(from: target)\n        |&gt; duration.format\n      )\n    False -&gt; io.println(&quot;We are on time!&quot;)\n  }\n  // -&gt; We are late by 54 minutes\n}\n```\n\n#### Iterating Over a Date Range\n\n```gleam\nimport tempo/date\nimport tempo/period\n\npub fn main() {\n  date.literal(&quot;2024-06-21&quot;)\n  |&gt; date.as_period(end: date.literal(&quot;2024-06-24&quot;))\n  |&gt; period.comprising_dates\n  // -&gt; [2024-06-21, 2024-06-22, 2024-06-23, 2024-06-24]\n\n  date.literal(&quot;2024-06-21&quot;)\n  |&gt; date.as_period(end: date.literal(&quot;2024-07-08&quot;))\n  |&gt; period.comprising_months\n  // -&gt; [tempo.Jun, tempo.Jul]\n}\n```\n\n#### Waiting Until a Specific Time of Day\n\n```gleam\nimport gleam/erlang/process\nimport tempo/duration\nimport tempo/time\nimport tempo/instant\n\npub fn main() {\n  // Sleep until 8:25 if we start before then.\n  instant.now()\n  |&gt; instant.as_local_time\n  |&gt; time.until(time.literal(&quot;08:25:00&quot;))\n  |&gt; duration.as_milliseconds\n  |&gt; process.sleep\n\n  // Now that it is 8:25, do what we need to do.\n  &quot;Hello, world!&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gtempo&gt;.\n\n## Time Zone and Leap Second Considerations\n\nThis package purposefully **ignores leap seconds** and **will not convert between time zones unless given a timezone provider**. Try to design your application so time zones do not have to be converted between and leap seconds are trivial. More below.\n\nBoth time zones and leap seconds require maintaining a manually updated database of location offsets and leap seconds. This burdens any application that uses them to keep their dependencies up to date and burdens the package by either invalidating all previous versions when an update needs to be made or providing hot timezone data updates.\n\nIf at all possible, try to design your application so that time zones do not have to be converted between. Client machines should have information about their time zone offset that can be polled and used for current time time zone conversions. This package will allow you to convert between local time and UTC time on the same date as the system date natively.\n\nSince this package ignores leap seconds, historical leap seconds are ignored when doing comparisons and durations. Please keep this in mind when designing your applications. Leap seconds can still be parsed from ISO 8601 strings and will be compared correctly to other times, but will not be preserved when converting to any other time representation (including changing the offset).\n\nWhen getting the system time, leap second accounting depends on the host&#39;s time implementation.\n\nTo account for leap seconds with this package, use a separate leap seconds provider package to compare dates (this leap second provider is fictional):\n\n```gleam\nimport tempo/datetime\nimport leap_second\n\npub fn main() {\n  datetime.literal(&quot;1972-06-30T23:59:59Z&quot;)\n  |&gt; leap_second.difference(from: datetime.literal(&quot;1972-07-01T00:00:00Z&quot;))\n  // -&gt; &quot;00:00:02&quot;\n}\n```\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"tempo/error","title":"DateOutOfBoundsError","content":"pub type DateOutOfBoundsError {\n  DateDayOutOfBounds(input: String)\n  DateMonthOutOfBounds(input: String)\n  DateYearOutOfBounds(input: String)\n}\n\nDateDayOutOfBounds(input: String)\n\n\nDateMonthOutOfBounds(input: String)\n\n\nDateYearOutOfBounds(input: String)\n\n\nSynonyms:\ntempo/error.DateOutOfBoundsError\ntempo/error DateOutOfBoundsError","url":"tempo/error.html#DateOutOfBoundsError"},{"doc":"tempo/error","title":"DateParseError","content":"pub type DateParseError {\n  DateInvalidFormat(input: String)\n  DateOutOfBounds(input: String, cause: DateOutOfBoundsError)\n}\n\nDateInvalidFormat(input: String)\n\n\nDateOutOfBounds(input: String, cause: DateOutOfBoundsError)\n\n\nSynonyms:\ntempo/error.DateParseError\ntempo/error DateParseError","url":"tempo/error.html#DateParseError"},{"doc":"tempo/error","title":"DateTimeOutOfBoundsError","content":"pub type DateTimeOutOfBoundsError {\n  DateTimeDateOutOfBounds(\n    input: String,\n    cause: DateOutOfBoundsError,\n  )\n  DateTimeTimeOutOfBounds(\n    input: String,\n    cause: TimeOutOfBoundsError,\n  )\n  DateTimeOffsetOutOfBounds(input: String)\n}\n\nDateTimeDateOutOfBounds(\n  input: String,\n  cause: DateOutOfBoundsError,\n)\n\n\nDateTimeTimeOutOfBounds(\n  input: String,\n  cause: TimeOutOfBoundsError,\n)\n\n\nDateTimeOffsetOutOfBounds(input: String)\n\n\nSynonyms:\ntempo/error.DateTimeOutOfBoundsError\ntempo/error DateTimeOutOfBoundsError","url":"tempo/error.html#DateTimeOutOfBoundsError"},{"doc":"tempo/error","title":"DateTimeParseError","content":"pub type DateTimeParseError {\n  DateTimeInvalidFormat(input: String)\n  DateTimeDateParseError(input: String, cause: DateParseError)\n  DateTimeTimeParseError(input: String, cause: TimeParseError)\n  DateTimeOffsetParseError(\n    input: String,\n    cause: OffsetParseError,\n  )\n}\n\nDateTimeInvalidFormat(input: String)\n\n\nDateTimeDateParseError(input: String, cause: DateParseError)\n\n\nDateTimeTimeParseError(input: String, cause: TimeParseError)\n\n\nDateTimeOffsetParseError(input: String, cause: OffsetParseError)\n\n\nSynonyms:\ntempo/error.DateTimeParseError\ntempo/error DateTimeParseError","url":"tempo/error.html#DateTimeParseError"},{"doc":"tempo/error","title":"NaiveDateTimeParseError","content":"pub type NaiveDateTimeParseError {\n  NaiveDateTimeInvalidFormat(input: String)\n  NaiveDateTimeDateParseError(\n    input: String,\n    cause: DateParseError,\n  )\n  NaiveDateTimeTimeParseError(\n    input: String,\n    cause: TimeParseError,\n  )\n}\n\nNaiveDateTimeInvalidFormat(input: String)\n\n\nNaiveDateTimeDateParseError(input: String, cause: DateParseError)\n\n\nNaiveDateTimeTimeParseError(input: String, cause: TimeParseError)\n\n\nSynonyms:\ntempo/error.NaiveDateTimeParseError\ntempo/error NaiveDateTimeParseError","url":"tempo/error.html#NaiveDateTimeParseError"},{"doc":"tempo/error","title":"OffsetParseError","content":"pub type OffsetParseError {\n  OffsetInvalidFormat(input: String)\n  OffsetOutOfBounds(input: String)\n}\n\nOffsetInvalidFormat(input: String)\n\n\nOffsetOutOfBounds(input: String)\n\n\nSynonyms:\ntempo/error.OffsetParseError\ntempo/error OffsetParseError","url":"tempo/error.html#OffsetParseError"},{"doc":"tempo/error","title":"TimeOutOfBoundsError","content":"pub type TimeOutOfBoundsError {\n  TimeHourOutOfBounds(input: String)\n  TimeMinuteOutOfBounds(input: String)\n  TimeSecondOutOfBounds(input: String)\n  TimeMicroSecondOutOfBounds(input: String)\n}\n\nTimeHourOutOfBounds(input: String)\n\n\nTimeMinuteOutOfBounds(input: String)\n\n\nTimeSecondOutOfBounds(input: String)\n\n\nTimeMicroSecondOutOfBounds(input: String)\n\n\nSynonyms:\ntempo/error.TimeOutOfBoundsError\ntempo/error TimeOutOfBoundsError","url":"tempo/error.html#TimeOutOfBoundsError"},{"doc":"tempo/error","title":"TimeParseError","content":"pub type TimeParseError {\n  TimeInvalidFormat(input: String)\n  TimeOutOfBounds(input: String, cause: TimeOutOfBoundsError)\n}\n\nTimeInvalidFormat(input: String)\n\n\nTimeOutOfBounds(input: String, cause: TimeOutOfBoundsError)\n\n\nSynonyms:\ntempo/error.TimeParseError\ntempo/error TimeParseError","url":"tempo/error.html#TimeParseError"},{"doc":"tempo/error","title":"tempo/error","content":"","url":"tempo/error.html"},{"doc":"tempo","title":"Date","content":"pub opaque type Date\n A date value. It represents a specific day on the civil calendar with no\n time of day associated with it.\n\nSynonyms:\ntempo.Date\ntempo Date","url":"tempo.html#Date"},{"doc":"tempo","title":"DateFormat","content":"pub type DateFormat {\n  ISO8601Date\n  CustomDate(format: String)\n  CustomDateLocalised(format: String, locale: Locale)\n}\n Provides common date formatting templates.\n \n The CustomDate format takes a format string that implements the same \n formatting directives as the nice Day.js \n library: https://day.js.org/docs/en/display/format.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] YYYY&quot;.\n \n Available custom format directives: YY (two-digit year), YYYY (four-digit year), M (month), \n MM (two-digit month), MMM (short month name), MMMM (full month name), \n D (day of the month), DD (two-digit day of the month), d (day of the week), \n dd (min day of the week), ddd (short day of week), and\n dddd (full day of the week).\nISO8601Date\n\n\nCustomDate(format: String)\n\n\nCustomDateLocalised(format: String, locale: Locale)\n\n\nSynonyms:\ntempo.DateFormat\ntempo DateFormat","url":"tempo.html#DateFormat"},{"doc":"tempo","title":"DateTime","content":"pub type DateTime {\n  DateTime(date: Date, time: Time, offset: Offset)\n  LocalDateTime(\n    date: Date,\n    time: Time,\n    offset: Offset,\n    tz: TimeZoneProvider,\n  )\n}\n A datetime value with a timezone offset associated with it. It has the \n most amount of information about a point in time, and can be compared to \n all other types in this package by getting its lesser parts.\nDateTime(date: Date, time: Time, offset: Offset)\n\n\nLocalDateTime(\n  date: Date,\n  time: Time,\n  offset: Offset,\n  tz: TimeZoneProvider,\n)\n\n\nSynonyms:\ntempo.DateTime\ntempo DateTime","url":"tempo.html#DateTime"},{"doc":"tempo","title":"DateTimeFormat","content":"pub type DateTimeFormat {\n  ISO8601Seconds\n  ISO8601Milli\n  ISO8601Micro\n  HTTP\n  Custom(format: String)\n  CustomLocalised(format: String, locale: Locale)\n  DateFormat(DateFormat)\n  TimeFormat(TimeFormat)\n}\n Provides common datetime formatting templates.\n \n The Custom format takes a format string that implements the same \n formatting directives as the nice Day.js \n library: https://day.js.org/docs/en/display/format, plus condensed offsets.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] YYYY&quot;.\n \n Available custom format directives: YY (two-digit year), YYYY (four-digit year), M (month), \n MM (two-digit month), MMM (short month name), MMMM (full month name), \n D (day of the month), DD (two-digint day of the month), d (day of the week), \n dd (min day of the week), ddd (short day of week), dddd (full day of the week), \n H (hour), HH (two-digit hour), h (12-hour clock hour), hh \n (two-digit 12-hour clock hour), m (minute), mm (two-digit minute),\n s (second), ss (two-digit second), SSS (millisecond), SSSS (microsecond), \n Z (offset from UTC), ZZ (offset from UTC with no &quot;:&quot;),\n z (short offset from UTC &quot;-04&quot;, &quot;Z&quot;), A (AM/PM), a (am/pm).\nISO8601Seconds\n\n\nISO8601Milli\n\n\nISO8601Micro\n\n\nHTTP\n\n\nCustom(format: String)\n\n\nCustomLocalised(format: String, locale: Locale)\n\n\nDateFormat(DateFormat)\n\n\nTimeFormat(TimeFormat)\n\n\nSynonyms:\ntempo.DateTimeFormat\ntempo DateTimeFormat","url":"tempo.html#DateTimeFormat"},{"doc":"tempo","title":"Duration","content":"pub opaque type Duration\n A duration between two times. It represents a range of time values and\n can be span more than a day. It can be used to calculate the number of\n days, weeks, hours, minutes, or seconds between two times, but cannot\n accurately be used to calculate the number of years or months between.\n \n It is also used as the basis for specifying how to increase or decrease\n a datetime or time value.\n\nSynonyms:\ntempo.Duration\ntempo Duration","url":"tempo.html#Duration"},{"doc":"tempo","title":"Instant","content":"pub opaque type Instant\n A monotonic type that reperesents a unique point in time on the host system. \n It can be converted to all other date time types, but cannot be serialized\n itself. An instant constructed on one host has no meaningful purpose on\n another host.\n\nSynonyms:\ntempo.Instant\ntempo Instant","url":"tempo.html#Instant"},{"doc":"tempo","title":"Locale","content":"pub type Locale\n A type that provides information on how to format dates and times for a \n specific region or language.\n\nSynonyms:\ntempo.Locale\ntempo Locale","url":"tempo.html#Locale"},{"doc":"tempo","title":"Month","content":"pub type Month {\n  Jan\n  Feb\n  Mar\n  Apr\n  May\n  Jun\n  Jul\n  Aug\n  Sep\n  Oct\n  Nov\n  Dec\n}\n A specific month on the civil calendar. \nJan\n\n\nFeb\n\n\nMar\n\n\nApr\n\n\nMay\n\n\nJun\n\n\nJul\n\n\nAug\n\n\nSep\n\n\nOct\n\n\nNov\n\n\nDec\n\n\nSynonyms:\ntempo.Month\ntempo Month","url":"tempo.html#Month"},{"doc":"tempo","title":"MonthYear","content":"pub type MonthYear {\n  MonthYear(month: Month, year: Int)\n}\n A month in a specific year.\nMonthYear(month: Month, year: Int)\n\n\nSynonyms:\ntempo.MonthYear\ntempo MonthYear","url":"tempo.html#MonthYear"},{"doc":"tempo","title":"NaiveDateTime","content":"pub type NaiveDateTime {\n  NaiveDateTime(date: Date, time: Time)\n}\n A datetime value that does not have a timezone or offset associated with it. \n It cannot be compared to datetimes with a timezone offset accurately, but\n can be compared to dates, times, and other naive datetimes.\nNaiveDateTime(date: Date, time: Time)\n\n\nSynonyms:\ntempo.NaiveDateTime\ntempo NaiveDateTime","url":"tempo.html#NaiveDateTime"},{"doc":"tempo","title":"NaiveDateTimeFormat","content":"pub type NaiveDateTimeFormat {\n  NaiveISO8601Seconds\n  NaiveISO8601Milli\n  NaiveISO8601Micro\n  CustomNaive(format: String)\n  CustomNaiveLocalised(format: String, locale: Locale)\n  NaiveDateFormat(DateFormat)\n  NaiveTimeFormat(TimeFormat)\n}\n Provides common naive datetime formatting templates.\n \n The CustomNaive format takes a format string that implements the same \n formatting directives as the nice Day.js \n library: https://day.js.org/docs/en/display/format, plus condensed offsets.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] YYYY&quot;.\n \n Available custom format directives: YY (two-digit year), YYYY (four-digit year), M (month), \n MM (two-digit month), MMM (short month name), MMMM (full month name), \n D (day of the month), DD (two-digint day of the month), d (day of the week), \n dd (min day of the week), ddd (short day of week), dddd (full day of the week), \n H (hour), HH (two-digit hour), h (12-hour clock hour), hh \n (two-digit 12-hour clock hour), m (minute), mm (two-digit minute),\n s (second), ss (two-digit second), SSS (millisecond), SSSS (microsecond),\n Z (full offset from UTC in the format &quot;+-00:00&quot;), ZZ (full offset from UTC\n with no &quot;:&quot;), z (short offset from UTC as &quot;-04&quot; or &quot;Z&quot; if UTC), zz (full \n offset from UTC as &quot;-04:00&quot; or &quot;Z&quot; if UTC), A (AM/PM), a (am/pm).\nNaiveISO8601Seconds\n\n\nNaiveISO8601Milli\n\n\nNaiveISO8601Micro\n\n\nCustomNaive(format: String)\n\n\nCustomNaiveLocalised(format: String, locale: Locale)\n\n\nNaiveDateFormat(DateFormat)\n\n\nNaiveTimeFormat(TimeFormat)\n\n\nSynonyms:\ntempo.NaiveDateTimeFormat\ntempo NaiveDateTimeFormat","url":"tempo.html#NaiveDateTimeFormat"},{"doc":"tempo","title":"Offset","content":"pub opaque type Offset\n A datetime offset value. It represents the difference between UTC and the\n datetime value it is associated with.\n\nSynonyms:\ntempo.Offset\ntempo Offset","url":"tempo.html#Offset"},{"doc":"tempo","title":"Period","content":"pub opaque type Period\n A period between two calendar datetimes. It represents a range of\n datetimes and can be used to calculate the number of days, weeks, months, \n or years between two dates. It can also be interated over and datetime \n values can be checked for inclusion in the period.\n\nSynonyms:\ntempo.Period\ntempo Period","url":"tempo.html#Period"},{"doc":"tempo","title":"Time","content":"pub opaque type Time\n A time of day value. It represents a specific time on an unspecified date.\n It cannot be greater than 24 hours or less than 0 hours. It has microsecond\n precision.\n\nSynonyms:\ntempo.Time\ntempo Time","url":"tempo.html#Time"},{"doc":"tempo","title":"TimeFormat","content":"pub type TimeFormat {\n  ISO8601Time\n  ISO8601TimeMilli\n  ISO8601TimeMicro\n  CustomTime(format: String)\n  CustomTimeLocalised(format: String, locale: Locale)\n}\n Provides common time formatting templates.\n \n The CustomTime format takes a format string that implements the same \n formatting directives as the nice Day.js \n library: https://day.js.org/docs/en/display/format.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] HH&quot;.\n \n Available custom format directives: H (hour), HH (two-digit hour), h (12-hour clock hour),\n hh (two-digit 12-hour clock hour), m (minute), mm (two-digit minute),\n s (second), ss (two-digit second), SSS (millisecond), SSSS (microsecond), \n A (AM/PM), a (am/pm).\nISO8601Time\n\n\nISO8601TimeMilli\n\n\nISO8601TimeMicro\n\n\nCustomTime(format: String)\n\n\nCustomTimeLocalised(format: String, locale: Locale)\n\n\nSynonyms:\ntempo.TimeFormat\ntempo TimeFormat","url":"tempo.html#TimeFormat"},{"doc":"tempo","title":"TimeZoneProvider","content":"pub type TimeZoneProvider {\n  TimeZoneProvider(\n    get_name: fn() -&gt; String,\n    calculate_offset: fn(NaiveDateTime) -&gt; Offset,\n  )\n}\n A type for external packages to provide so that datetimes can be converted\n between timezones. The package `gtz` was created to provide this and must\n be added as a project dependency separately.\nTimeZoneProvider(\n  get_name: fn() -&gt; String,\n  calculate_offset: fn(NaiveDateTime) -&gt; Offset,\n)\n\n\nSynonyms:\ntempo.TimeZoneProvider\ntempo TimeZoneProvider","url":"tempo.html#TimeZoneProvider"},{"doc":"tempo","title":"compare","content":"pub fn compare(to datetime: DateTime) -&gt; Order\n Compares the current system time to the provided datetime value.\n\n ## Example\n\n \n tempo.compare(datetime.literal(&quot;2024-12-26T00:00:00Z&quot;))\n // -&gt; order.Lt\nSynonyms:\ntempo.compare\ntempo compare","url":"tempo.html#compare"},{"doc":"tempo","title":"difference","content":"pub fn difference(from start: DateTime) -&gt; Duration\n Gets the difference between the current system datetime and the provided\n datetime.\n \n ## Example\n \n \n tempo.difference(from: datetime.literal(&quot;2024-10-26T00:00:00Z&quot;))\n |&gt; duration.format\n // -&gt; &quot;54 days, 13 hours, and 46 minutes&quot;\n \nSynonyms:\ntempo.difference\ntempo difference","url":"tempo.html#difference"},{"doc":"tempo","title":"format_local","content":"pub fn format_local(in format: DateTimeFormat) -&gt; String\n Formats the current local system time using the provided format.\n \n ## Example\n \n \n tempo.format_local(tempo.ISO8601Seconds)\n // -&gt; &quot;2024-12-26T12:32:34-04:00&quot;\n \nSynonyms:\ntempo.format_local\ntempo format_local","url":"tempo.html#format_local"},{"doc":"tempo","title":"format_utc","content":"pub fn format_utc(in format: DateTimeFormat) -&gt; String\n Formats the current UTC system time using the provided format.\n \n ## Example\n \n \n tempo.format_utc(tempo.ISO8601Seconds)\n // -&gt; &quot;2024-12-26T16:32:34Z&quot;\n \nSynonyms:\ntempo.format_utc\ntempo format_utc","url":"tempo.html#format_utc"},{"doc":"tempo","title":"is_earlier","content":"pub fn is_earlier(than datetime: DateTime) -&gt; Bool\n Checks if the current system time is earlier than the provided datetime.\n \n ## Example\n \n \n tempo.is_earlier(than: datetime.literal(&quot;2024-12-26T00:00:00Z&quot;))\n // -&gt; False\n \nSynonyms:\ntempo.is_earlier\ntempo is_earlier","url":"tempo.html#is_earlier"},{"doc":"tempo","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(to datetime: DateTime) -&gt; Bool\n Checks if the current system time is earlier or equal to the provided \n datetime.\n \n ## Example\n \n \n tempo.is_earlier_or_equal(to: datetime.literal(&quot;2024-12-26T00:00:00Z&quot;))\n // -&gt; True\n \nSynonyms:\ntempo.is_earlier_or_equal\ntempo is_earlier_or_equal","url":"tempo.html#is_earlier_or_equal"},{"doc":"tempo","title":"is_equal","content":"pub fn is_equal(to datetime: DateTime) -&gt; Bool\n Checks if the current system time is equal to the provided datetime.\n \n ## Example\n \n \n tempo.is_equal(to: datetime.literal(&quot;2024-12-26T00:00:00Z&quot;))\n // -&gt; False\nSynonyms:\ntempo.is_equal\ntempo is_equal","url":"tempo.html#is_equal"},{"doc":"tempo","title":"is_later","content":"pub fn is_later(than datetime: DateTime) -&gt; Bool\n Checks if the current system time is later than the provided datetime.\n \n ## Example\n \n \n tempo.is_later(than: datetime.literal(&quot;2024-12-26T00:00:00Z&quot;))\n // -&gt; True\n \nSynonyms:\ntempo.is_later\ntempo is_later","url":"tempo.html#is_later"},{"doc":"tempo","title":"is_later_or_equal","content":"pub fn is_later_or_equal(to datetime: DateTime) -&gt; Bool\n Checks if the current system time is later or equal to the provided \n datetime.\n \n ## Example\n \n \n tempo.is_later_or_equal(to: datetime.literal(&quot;2024-12-26T00:00:00Z&quot;))\n // -&gt; True\n \nSynonyms:\ntempo.is_later_or_equal\ntempo is_later_or_equal","url":"tempo.html#is_later_or_equal"},{"doc":"tempo","title":"parse_any","content":"pub fn parse_any(\n  str: String,\n) -&gt; #(Option(Date), Option(Time), Option(Offset))\n Tries to parse a given date string without a known format. It will not \n parse two digit years and will assume the month always comes before the \n day in a date. Always prefer to use a module&#39;s specific `parse` function\n when possible.\n \n Using pattern matching, you can explicitly specify what to with the \n missing values from the input. Many libaries will assume a missing time\n value means 00:00:00 or a missing offset means UTC. This design\n lets the user decide how fallbacks are handled. \n \n ## Example\n \n \n case tempo.parse_any(&quot;06/21/2024 at 01:42:11 PM&quot;) {\n   #(Some(date), Some(time), Some(offset)) -&gt;\n     datetime.new(date, time, offset)\n \n   #(Some(date), Some(time), None) -&gt;\n     datetime.new(date, time, offset.local())\n \n   _ -&gt; datetime.now_local()\n }\n // -&gt; datetime.literal(&quot;2024-06-21T13:42:11-04:00&quot;)\n \n \n \n tempo.parse_any(&quot;2024.06.21 11:32 AM -0400&quot;)\n // -&gt; #(\n //  Some(date.literal(&quot;2024-06-21&quot;)), \n //  Some(time.literal(&quot;11:32:00&quot;)),\n //  Some(offset.literal(&quot;-04:00&quot;))\n // )\n \n \n \n tempo.parse_any(&quot;Dec 25, 2024 at 6:00 AM&quot;)\n // -&gt; #(\n //  Some(date.literal(&quot;2024-12-25&quot;)), \n //  Some(time.literal(&quot;06:00:00&quot;)),\n //  None\n // )\n \nSynonyms:\ntempo.parse_any\ntempo parse_any","url":"tempo.html#parse_any"},{"doc":"tempo","title":"since","content":"pub fn since(start start: DateTime) -&gt; Duration\n Gets the time since the provided datetime relative to the current system\n time. The same as `tempo.difference`, but a duration of 0 will be \n returned instead if the datetime is in the future.\n \n ## Example\n \n \n tempo.since(datetime.literal(&quot;2024-10-26T00:00:00Z&quot;))\n |&gt; duration.format\n // -&gt; &quot;54 days, 13 hours, and 46 minutes&quot;\n \n \n \n tempo.since(datetime.literal(&quot;9099-12-26T00:00:00Z&quot;))\n |&gt; duration.format\n // -&gt; &quot;none&quot;\n \nSynonyms:\ntempo.since\ntempo since","url":"tempo.html#since"},{"doc":"tempo","title":"until","content":"pub fn until(end end: DateTime) -&gt; Duration\n Gets the time until the provided datetime relative to the current system\n time. A duration of 0 will be returned if the datetime in the past.\n \n ## Example\n \n \n tempo.until(datetime.literal(&quot;2024-10-26T00:00:00Z&quot;))\n |&gt; duration.format\n // -&gt; &quot;none&quot;\n \n \n \n tempo.until(datetime.literal(&quot;2025-02-26T00:00:00Z&quot;))\n |&gt; duration.format\n // -&gt; &quot;54 days, 13 hours, and 46 minutes&quot;\n \nSynonyms:\ntempo.until\ntempo until","url":"tempo.html#until"},{"doc":"tempo","title":"tempo","content":" The main module of this package. Contains most package types and general \n purpose functions.\n Look in specific modules for more functionality!","url":"tempo.html"},{"doc":"tempo/month","title":"months","content":"pub const months: List(Month)\n An ordered list of all months in the year.\n -&gt; [Jan, Feb, Mar, Apr, May, Jun, Jul, Aug, Sep, Oct, Nov, Dec]\nSynonyms:\ntempo/month.months\ntempo/month months","url":"tempo/month.html#months"},{"doc":"tempo/month","title":"days","content":"pub fn days(of month: Month, in year: Int) -&gt; Int\n Returns the number of days in a month.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.days\n // -&gt; 30\n \n \n \n date.literal(&quot;2024-12-03&quot;)\n |&gt; date.get_month\n |&gt; month.days\n // -&gt; 31\n \nSynonyms:\ntempo/month.days\ntempo/month days","url":"tempo/month.html#days"},{"doc":"tempo/month","title":"from_int","content":"pub fn from_int(month: Int) -&gt; Result(Month, Nil)\n Gets a month from an integer representing the order of the month on the \n civil calendar.\n \n ## Example\n \n \n month.from_int(6)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_int(13)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_int\ntempo/month from_int","url":"tempo/month.html#from_int"},{"doc":"tempo/month","title":"from_long_string","content":"pub fn from_long_string(month: String) -&gt; Result(Month, Nil)\n Gets a month from a long month string.\n \n ## Example\n \n \n month.from_long_string(&quot;June&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_long_string(&quot;Jun&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_long_string\ntempo/month from_long_string","url":"tempo/month.html#from_long_string"},{"doc":"tempo/month","title":"from_short_string","content":"pub fn from_short_string(month: String) -&gt; Result(Month, Nil)\n Gets a month from a short month string.\n \n ## Example\n \n \n month.from_short_string(&quot;Jun&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_short_string(&quot;June&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_short_string\ntempo/month from_short_string","url":"tempo/month.html#from_short_string"},{"doc":"tempo/month","title":"from_string","content":"pub fn from_string(month: String) -&gt; Result(Month, Nil)\n Gets a month from a month string.\n \n ## Example\n \n \n month.from_string(&quot;Jun&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_string(&quot;June&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_string(&quot;Hello&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_string\ntempo/month from_string","url":"tempo/month.html#from_string"},{"doc":"tempo/month","title":"to_int","content":"pub fn to_int(month: Month) -&gt; Int\n Returns a month&#39;s number on the civil calendar.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.to_int\n // -&gt; 6\n \nSynonyms:\ntempo/month.to_int\ntempo/month to_int","url":"tempo/month.html#to_int"},{"doc":"tempo/month","title":"to_long_string","content":"pub fn to_long_string(month: Month) -&gt; String\n Returns a month&#39;s long name.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.to_short_string\n // -&gt; &quot;June&quot;\n \nSynonyms:\ntempo/month.to_long_string\ntempo/month to_long_string","url":"tempo/month.html#to_long_string"},{"doc":"tempo/month","title":"to_short_string","content":"pub fn to_short_string(month: Month) -&gt; String\n Returns a month&#39;s short name.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.to_short_string\n // -&gt; &quot;Jun&quot;\n \nSynonyms:\ntempo/month.to_short_string\ntempo/month to_short_string","url":"tempo/month.html#to_short_string"},{"doc":"tempo/month","title":"tempo/month","content":" Functions to use with the `Month` type in Tempo.","url":"tempo/month.html"},{"doc":"tempo/date","title":"DayOfWeek","content":"pub type DayOfWeek {\n  Sun\n  Mon\n  Tue\n  Wed\n  Thu\n  Fri\n  Sat\n}\n A named day of the week.\nSun\n\n\nMon\n\n\nTue\n\n\nWed\n\n\nThu\n\n\nFri\n\n\nSat\n\n\nSynonyms:\ntempo/date.DayOfWeek\ntempo/date DayOfWeek","url":"tempo/date.html#DayOfWeek"},{"doc":"tempo/date","title":"add","content":"pub fn add(date: Date, days days: Int) -&gt; Date\n Adds a number of days to a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.add(days: 1)\n // -&gt; date.literal(&quot;2024-06-13&quot;)\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.add(days: 12)\n // -&gt; date.literal(&quot;2024-06-24&quot;)\n \nSynonyms:\ntempo/date.add\ntempo/date add","url":"tempo/date.html#add"},{"doc":"tempo/date","title":"as_period","content":"pub fn as_period(start start: Date, end end: Date) -&gt; Period\n Creates a period between the first date at 00:00:00 and the second date at\n 24:00:00. Periods only represent positive datetime differences.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.as_period(end: date.literal(&quot;2024-06-23&quot;))\n |&gt; period.as_days\n // -&gt; 11\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.as_period(start: date.literal(&quot;2024-06-09&quot;))\n |&gt; period.comprising_dates\n // -&gt; [&quot;2024-06-09&quot;, &quot;2024-06-10&quot;, &quot;2024-06-11&quot;, &quot;2024-06-12&quot;]\n \nSynonyms:\ntempo/date.as_period\ntempo/date as_period","url":"tempo/date.html#as_period"},{"doc":"tempo/date","title":"compare","content":"pub fn compare(a: Date, to b: Date) -&gt; Order\n Compares two dates.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.compare(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; order.Eq\n \n \n \n date.literal(&quot;2024-05-12&quot;)\n |&gt; date.compare(to: date.literal(&quot;2024-06-13&quot;))\n // -&gt; order.Lt\n \n \n \n date.literal(&quot;2034-06-12&quot;)\n |&gt; date.compare(to: date.literal(&quot;2024-06-11&quot;))\n // -&gt; order.Gt\n \nSynonyms:\ntempo/date.compare\ntempo/date compare","url":"tempo/date.html#compare"},{"doc":"tempo/date","title":"current_local","content":"pub fn current_local() -&gt; Date\n Gets the current local date of the host.\n \n ## Examples\n \n \n date.current_local()\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \nSynonyms:\ntempo/date.current_local\ntempo/date current_local","url":"tempo/date.html#current_local"},{"doc":"tempo/date","title":"current_utc","content":"pub fn current_utc() -&gt; Date\n Gets the current UTC date of the host.\n \n ## Examples\n \n \n date.current_utc()\n |&gt; date.to_string\n // -&gt; &quot;2024-06-14&quot;\n \nSynonyms:\ntempo/date.current_utc\ntempo/date current_utc","url":"tempo/date.html#current_utc"},{"doc":"tempo/date","title":"day_of_week_to_long_string","content":"pub fn day_of_week_to_long_string(\n  day_of_week: DayOfWeek,\n) -&gt; String\n Returns the long string representation of a day of the week.\n \n ## Examples\n \n \n date|&gt; tempo.date_get_day_of_week_to_long_string(date.Fri)\n // -&gt; &quot;Friday&quot;\n \nSynonyms:\ntempo/date.day_of_week_to_long_string\ntempo/date day_of_week_to_long_string","url":"tempo/date.html#day_of_week_to_long_string"},{"doc":"tempo/date","title":"day_of_week_to_short_string","content":"pub fn day_of_week_to_short_string(\n  day_of_week: DayOfWeek,\n) -&gt; String\n Returns the short string representation of a day of the week.\n \n ## Examples\n \n \n date|&gt; tempo.date_get_day_of_week_to_short_string(date.Mon)\n // -&gt; &quot;Mon&quot;\n \nSynonyms:\ntempo/date.day_of_week_to_short_string\ntempo/date day_of_week_to_short_string","url":"tempo/date.html#day_of_week_to_short_string"},{"doc":"tempo/date","title":"describe_out_of_bounds_error","content":"pub fn describe_out_of_bounds_error(\n  error: DateOutOfBoundsError,\n) -&gt; String\n Converts a date out of bounds error to a human readable error message.\n \n ## Example\n \n \n date.from_tuple(#(98, 6, 13))\n |&gt; snag.map_error(with: date.describe_out_of_bounds_error)\n // -&gt; snag.error(&quot;Year out of bounds in date: 98&quot;)\n \nSynonyms:\ntempo/date.describe_out_of_bounds_error\ntempo/date describe_out_of_bounds_error","url":"tempo/date.html#describe_out_of_bounds_error"},{"doc":"tempo/date","title":"describe_parse_error","content":"pub fn describe_parse_error(error: DateParseError) -&gt; String\n Converts a date parse error to a human readable error message.\n \n ## Example\n \n \n date.parse_any(&quot;01:32 PM&quot;)\n |&gt; snag.map_error(with: date.describe_parse_error)\n // -&gt; snag.error(&quot;Invalid date format: 01:32 PM&quot;)\n \nSynonyms:\ntempo/date.describe_parse_error\ntempo/date describe_parse_error","url":"tempo/date.html#describe_parse_error"},{"doc":"tempo/date","title":"difference","content":"pub fn difference(from a: Date, to b: Date) -&gt; Int\n Gets the difference between two dates.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-23&quot;))\n // -&gt; 11\n \n \n \n date.literal(&quot;2024-06-03&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-11&quot;))\n // -&gt; -9\n \nSynonyms:\ntempo/date.difference\ntempo/date difference","url":"tempo/date.html#difference"},{"doc":"tempo/date","title":"first_of_month","content":"pub fn first_of_month(for date: Date) -&gt; Date\n Gets the first date of the month a date occurs in.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-21&quot;)\n |&gt; date.first_of_month\n // -&gt; date.literal(&quot;2024-06-01&quot;)\n \nSynonyms:\ntempo/date.first_of_month\ntempo/date first_of_month","url":"tempo/date.html#first_of_month"},{"doc":"tempo/date","title":"format","content":"pub fn format(date: Date, in format: DateFormat) -&gt; String\n Formats a date value into a string using the provided date format.\n \n ## Example\n \n \n datetime.literal(&quot;2024-12-26T13:02:01-04:00&quot;)\n |&gt; datetime.format(tempo.ISO8601Date)\n // -&gt; &quot;2024-12-26&quot;\n \n \n \n datetime.literal(&quot;2024-06-21T13:42:11.314-04:00&quot;)\n |&gt; datetime.format(tempo.CustomDate(&quot;ddd @ h:mm A (z)&quot;))\n // -&gt; &quot;Fri @ 1:42 PM (-04)&quot;\n \n \n \n datetime.literal(&quot;2024-06-03T09:02:01-04:00&quot;)\n |&gt; datetime.format(tempo.CustomDate(&quot;YY YYYY M MM MMM MMMM D DD d dd ddd&quot;))\n // -------------------------------&gt; &quot;24 2024 6 06 Jun June 3 03 1 Mo Mon&quot;\n \n \n  \n datetime.literal(&quot;2024-06-03T09:02:01.014920202-00:00&quot;)\n |&gt; datetime.format(tempo.CustomDate(&quot;dddd SSS SSSS SSSSS Z ZZ z&quot;))\n // -&gt; &quot;Monday 014 014920 014920202 -00:00 -0000 Z&quot;\n \n \n \n datetime.literal(&quot;2024-06-03T13:02:01-04:00&quot;)\n |&gt; datetime.format(tempo.CustomDate((&quot;H HH h hh m mm s ss a A [An ant]&quot;))\n // -------------------------------&gt; &quot;13 13 1 01 2 02 1 01 pm PM An ant&quot;\n \nSynonyms:\ntempo/date.format\ntempo/date format","url":"tempo/date.html#format"},{"doc":"tempo/date","title":"from_dynamic_string","content":"pub fn from_dynamic_string(\n  dynamic_string: Dynamic,\n) -&gt; Result(Date, List(DecodeError))\n Checks if a dynamic value is a valid date string, and returns the\n date if it is.\n \n ## Examples\n \n \n dynamic.from(&quot;2024-06-21&quot;)\n |&gt; date.from_dynamic_string\n // -&gt; Ok(date.literal(&quot;2024-06-21&quot;))\n \n \n \n dynamic.from(&quot;153&quot;)\n |&gt; datetime.from_dynamic_string\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;tempo.Date&quot;,\n //     found: &quot;Invalid format: 153&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/date.from_dynamic_string\ntempo/date from_dynamic_string","url":"tempo/date.html#from_dynamic_string"},{"doc":"tempo/date","title":"from_string","content":"pub fn from_string(date: String) -&gt; Result(Date, DateParseError)\n Parses a date string in the format `YYYY-MM-DD`, `YYYY-M-D`, `YYYY/MM/DD`, \n `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`, `YYYY_M_D`, `YYYY MM DD`,\n `YYYY M D`, or `YYYYMMDD`.\n \n ## Examples\n \n \n date.from_string(&quot;2024-06-13&quot;)\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.from_string(&quot;20240613&quot;)\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.from_string(&quot;2409&quot;)\n // -&gt; Error(tempo_error.DateInvalidFormat)\n \nSynonyms:\ntempo/date.from_string\ntempo/date from_string","url":"tempo/date.html#from_string"},{"doc":"tempo/date","title":"from_tuple","content":"pub fn from_tuple(\n  date: #(Int, Int, Int),\n) -&gt; Result(Date, DateOutOfBoundsError)\n Returns a date value from a tuple of ints if the values represent the \n years, month, and day of a valid date. The year must be greater than 1000.\n \n Years less than 1000 are technically valid years, but are not common \n and usually indicate that either a non-year value was passed as the year\n or a two digit year was passed (which are too abiguous to be confidently\n accepted).\n \n ## Examples\n \n \n date.from_tuple(#(2024, 6, 13))\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.from_tuple(#(98, 6, 13))\n // -&gt; Error(tempo_error.DateOutOfBounds)\n \nSynonyms:\ntempo/date.from_tuple\ntempo/date from_tuple","url":"tempo/date.html#from_tuple"},{"doc":"tempo/date","title":"get_day","content":"pub fn get_day(date: Date) -&gt; Int\n Gets the day value of a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_day\n // -&gt; 13\n \nSynonyms:\ntempo/date.get_day\ntempo/date get_day","url":"tempo/date.html#get_day"},{"doc":"tempo/date","title":"get_month","content":"pub fn get_month(date: Date) -&gt; Month\n Gets the month value of a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n // -&gt; tempo.Jun\n \nSynonyms:\ntempo/date.get_month\ntempo/date get_month","url":"tempo/date.html#get_month"},{"doc":"tempo/date","title":"get_month_year","content":"pub fn get_month_year(date: Date) -&gt; MonthYear\n Gets the month value of a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month_year\n // -&gt; tempo.MonthYear(tempo.Jun, 2024)\n \nSynonyms:\ntempo/date.get_month_year\ntempo/date get_month_year","url":"tempo/date.html#get_month_year"},{"doc":"tempo/date","title":"get_year","content":"pub fn get_year(date: Date) -&gt; Int\n Gets the year value of a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_year\n // -&gt; 2024\n \nSynonyms:\ntempo/date.get_year\ntempo/date get_year","url":"tempo/date.html#get_year"},{"doc":"tempo/date","title":"is_earlier","content":"pub fn is_earlier(a: Date, than b: Date) -&gt; Bool\n Checks of the first date is earlier than the second date.\n\n ## Examples\n\n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier(than: date.literal(&quot;2024-06-13&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier(than: date.literal(&quot;2024-06-12&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_earlier\ntempo/date is_earlier","url":"tempo/date.html#is_earlier"},{"doc":"tempo/date","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(a: Date, to b: Date) -&gt; Bool\n Checks if the first date is earlier than or equal to the second date.\n \n ## Examples\n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier_or_equal(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier_or_equal(to: date.literal(&quot;2024-06-11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_earlier_or_equal\ntempo/date is_earlier_or_equal","url":"tempo/date.html#is_earlier_or_equal"},{"doc":"tempo/date","title":"is_equal","content":"pub fn is_equal(a: Date, to b: Date) -&gt; Bool\n Checks if two dates are equal.\n\n ## Example\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_equal(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; True\n \nSynonyms:\ntempo/date.is_equal\ntempo/date is_equal","url":"tempo/date.html#is_equal"},{"doc":"tempo/date","title":"is_later","content":"pub fn is_later(a: Date, than b: Date) -&gt; Bool\n Checks if the first date is later than the second date.\n\n ## Examples\n\n \n date.literal(&quot;2024-06-14&quot;)\n |&gt; date.is_later(than: date.literal(&quot;2024-06-13&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_later(than: date.literal(&quot;2024-06-12&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_later\ntempo/date is_later","url":"tempo/date.html#is_later"},{"doc":"tempo/date","title":"is_later_or_equal","content":"pub fn is_later_or_equal(a: Date, to b: Date) -&gt; Bool\n Checks if the first date is later than or equal to the second date.\n \n ## Examples\n\n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_later_or_equal(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_later_or_equal(to: date.literal(&quot;2024-06-13&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_later_or_equal\ntempo/date is_later_or_equal","url":"tempo/date.html#is_later_or_equal"},{"doc":"tempo/date","title":"is_weekend","content":"pub fn is_weekend(date: Date) -&gt; Bool\n Checks if a date falls in a weekend.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-22&quot;)\n |&gt; date.is_weekend\n // -&gt; True\n \nSynonyms:\ntempo/date.is_weekend\ntempo/date is_weekend","url":"tempo/date.html#is_weekend"},{"doc":"tempo/date","title":"last_of_month","content":"pub fn last_of_month(for date: Date) -&gt; Date\n Gets the last date of the month a date occurs in.\n \n ## Examples\n \n \n date.literal(&quot;2024-02-13&quot;)\n |&gt; date.last_of_month\n // -&gt; date.literal(&quot;2024-02-29&quot;)\n \nSynonyms:\ntempo/date.last_of_month\ntempo/date last_of_month","url":"tempo/date.html#last_of_month"},{"doc":"tempo/date","title":"literal","content":"pub fn literal(date: String) -&gt; Date\n Creates a new date value from a string literal, but will panic if\n the string is invalid. Accepted formats are `YYYY-MM-DD`, `YYYY-M-D`,\n `YYYY/MM/DD`, `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`,\n `YYYY_M_D`, `YYYY MM DD`, `YYYY M D`, or `YYYYMMDD`.\n \n Useful for declaring date literals that you know are valid within your  \n program.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \n \n \n date.literal(&quot;20240613&quot;)\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \n \n \n date.literal(&quot;2409&quot;)\n // -&gt; panic\n \nSynonyms:\ntempo/date.literal\ntempo/date literal","url":"tempo/date.html#literal"},{"doc":"tempo/date","title":"new","content":"pub fn new(\n  year year: Int,\n  month month: Int,\n  day day: Int,\n) -&gt; Result(Date, DateOutOfBoundsError)\n Creates a new date and validates it.\n \n ## Examples\n \n \n date.new(2024, 6, 13)\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.new(2024, 6, 31)\n // -&gt; Error(tempo_error.DateOutOfBounds)\n \nSynonyms:\ntempo/date.new\ntempo/date new","url":"tempo/date.html#new"},{"doc":"tempo/date","title":"next_day_of_week","content":"pub fn next_day_of_week(\n  date date: Date,\n  day_of_week dow: DayOfWeek,\n) -&gt; Date\n Gets the date of the next specified day of the week, exclusive of\n the passed date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-21&quot;)\n |&gt; date.next_day_of_week(date.Mon)\n // -&gt; date.literal(&quot;2024-06-24&quot;)\n \n \n \n date.literal(&quot;2024-06-21&quot;)\n |&gt; date.next_day_of_week(date.Fri)\n // -&gt; date.literal(&quot;2024-06-28&quot;)\n \nSynonyms:\ntempo/date.next_day_of_week\ntempo/date next_day_of_week","url":"tempo/date.html#next_day_of_week"},{"doc":"tempo/date","title":"parse","content":"pub fn parse(\n  str: String,\n  in format: DateFormat,\n) -&gt; Result(Date, DateParseError)\n Parses a date string in the provided format. Always prefer using\n this over `parse_any`. All parsed formats must have all parts of a date. \n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] YYYY&quot;.\n \n Available directives: YY (two-digit year), YYYY (four-digit year), M (month), \n MM (two-digit month), MMM (short month name), MMMM (full month name), \n D (day of the month), DD (two-digit day of the month),\n \n ## Example\n \n \n date.parse(&quot;2024/06/08, 13:42:11&quot;, &quot;YYYY/MM/DD&quot;)\n // -&gt; Ok(date.literal(&quot;2024-06-08&quot;))\n \n \n \n date.parse(&quot;January 13, 2024&quot;, &quot;MMMM DD, YYYY&quot;)\n // -&gt; Ok(date.literal(&quot;2024-01-13&quot;))\n \n \n \n date.parse(&quot;Hi! 2024 11 13&quot;, &quot;[Hi!] YYYY M D&quot;)\n // -&gt; Ok(date.literal(&quot;2024-11-13&quot;))\n \nSynonyms:\ntempo/date.parse\ntempo/date parse","url":"tempo/date.html#parse"},{"doc":"tempo/date","title":"parse_any","content":"pub fn parse_any(str: String) -&gt; Result(Date, DateParseError)\n Tries to parse a given date string without a known format. It will not \n parse two digit years and will assume the month always comes before the \n day in a date. Will leave out any time or offset values present.\n \n ## Example\n \n \n date.parse_any(&quot;2024.06.21 01:32 PM -04:00&quot;)\n // -&gt; Ok(date.literal(&quot;2024-06-21&quot;))\n \n \n \n date.parse_any(&quot;2024.06.21&quot;)\n // -&gt; Ok(date.literal(&quot;2024-06-21&quot;))\n \nSynonyms:\ntempo/date.parse_any\ntempo/date parse_any","url":"tempo/date.html#parse_any"},{"doc":"tempo/date","title":"prior_day_of_week","content":"pub fn prior_day_of_week(\n  date date: Date,\n  day_of_week dow: DayOfWeek,\n) -&gt; Date\n Gets the date of the prior specified day of the week, exclusive of\n the passed date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-21&quot;)\n |&gt; date.prior_day_of_week(date.Mon)\n // -&gt; date.literal(&quot;2024-06-17&quot;)\n \n \n \n date.literal(&quot;2024-06-21&quot;)\n |&gt; date.prior_day_of_week(date.Fri)\n // -&gt; date.literal(&quot;2024-06-14&quot;)\n \nSynonyms:\ntempo/date.prior_day_of_week\ntempo/date prior_day_of_week","url":"tempo/date.html#prior_day_of_week"},{"doc":"tempo/date","title":"subtract","content":"pub fn subtract(date: Date, days days: Int) -&gt; Date\n Subtracts a number of days from a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.subtract(days: 1)\n // -&gt; date.literal(&quot;2024-06-11&quot;)\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.subtract(days: 12)\n // -&gt; date.literal(&quot;2024-05-31&quot;)\n \nSynonyms:\ntempo/date.subtract\ntempo/date subtract","url":"tempo/date.html#subtract"},{"doc":"tempo/date","title":"to_day_of_week","content":"pub fn to_day_of_week(date: Date) -&gt; DayOfWeek\n Returns the day of week a date falls on.\n Will be incorrect for dates before 1752 and dates after 2300.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-20&quot;)\n |&gt; date.to_day_of_week\n // -&gt; Thur\n \nSynonyms:\ntempo/date.to_day_of_week\ntempo/date to_day_of_week","url":"tempo/date.html#to_day_of_week"},{"doc":"tempo/date","title":"to_day_of_week_number","content":"pub fn to_day_of_week_number(date: Date) -&gt; Int\n Returns the number of the day of week a date falls on.\n Will be incorrect for dates before 1752 and dates after 2300.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-21&quot;)\n |&gt; date.to_day_of_week_number\n // -&gt; 5\n \nSynonyms:\ntempo/date.to_day_of_week_number\ntempo/date to_day_of_week_number","url":"tempo/date.html#to_day_of_week_number"},{"doc":"tempo/date","title":"to_string","content":"pub fn to_string(date: Date) -&gt; String\n Returns a string representation of a date value in the format `YYYY-MM-DD`.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \nSynonyms:\ntempo/date.to_string\ntempo/date to_string","url":"tempo/date.html#to_string"},{"doc":"tempo/date","title":"to_tuple","content":"pub fn to_tuple(date: Date) -&gt; #(Int, Int, Int)\n Returns a tuple of ints from a date value that represent the year, month,\n and day of the date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-14&quot;)\n |&gt; date.to_tuple\n // -&gt; #(2024, 6, 14)\n \nSynonyms:\ntempo/date.to_tuple\ntempo/date to_tuple","url":"tempo/date.html#to_tuple"},{"doc":"tempo/date","title":"tempo/date","content":" Functions to use with the `Date` type in Tempo.\n \n ## Example\n \n ```gleam\n import tempo/date\n \n pub fn main() {\n   date.literal(&quot;2024-06-21&quot;)\n   |&gt; date.to_string\n   // -&gt; &quot;2024-06-21&quot;\n \n   date.parse(&quot;06/21/2024&quot;, tempo.CustomDate(&quot;MM/DD/YYYY&quot;))\n   |&gt; date.to_string\n   // -&gt; &quot;2024-06-21&quot;\n \n   date.current_local()\n   |&gt; date.to_string\n   // -&gt; &quot;2024-10-09&quot;\n }\n ```\n \n ```gleam\n import tempo/date\n \n pub fn is_older_than_a_week(date_str: String) {\n   let date = date.from_string(date_str)\n \n   date\n   |&gt; date.is_earlier(\n      than: date |&gt; date.subtract(days: 7)\n   )\n }\n ```","url":"tempo/date.html"},{"doc":"tempo/offset","title":"utc","content":"pub const utc: Offset\n The Tempo representation of the UTC offset.\nSynonyms:\ntempo/offset.utc\ntempo/offset utc","url":"tempo/offset.html#utc"},{"doc":"tempo/offset","title":"describe_parse_error","content":"pub fn describe_parse_error(error: OffsetParseError) -&gt; String\n Converts an offset parse error to a human readable error message.\n \n ## Example\n \n \n offset.from_string(&quot;bad offset&quot;)\n |&gt; snag.map_error(with: offset.describe_parse_error)\n // -&gt; snag.error(&quot;Invalid offset format: &quot;bad offset&quot;&quot;)\n \nSynonyms:\ntempo/offset.describe_parse_error\ntempo/offset describe_parse_error","url":"tempo/offset.html#describe_parse_error"},{"doc":"tempo/offset","title":"from_string","content":"pub fn from_string(\n  offset: String,\n) -&gt; Result(Offset, OffsetParseError)\n Tries to create a new offset from a string. Accepted formats are \n `(+-)hh:mm`, `(+-)hhmm`, `(+-)hh`, and `(+-)h`.\n \n ## Example\n \n \n offset.from_string(&quot;-04&quot;)\n |&gt; result.map(offset.to_string)\n // -&gt; Ok(&quot;-04:00&quot;)\n \nSynonyms:\ntempo/offset.from_string\ntempo/offset from_string","url":"tempo/offset.html#from_string"},{"doc":"tempo/offset","title":"literal","content":"pub fn literal(offset: String) -&gt; Offset\n Creates a new offset from a string literal, but will panic if the string\n is invalid. Accepted formats are `(+-)hh:mm`, `(+-)hhmm`, `(+-)hh`, and\n `(+-)h`.\n  \n Useful for declaring offset literals that you know are valid within your \n program.\n \n ## Example\n \n \n offset.literal(&quot;-04:00&quot;)\n |&gt; offset.to_string\n // -&gt; &quot;-04:00&quot;\n \nSynonyms:\ntempo/offset.literal\ntempo/offset literal","url":"tempo/offset.html#literal"},{"doc":"tempo/offset","title":"new","content":"pub fn new(offset_minutes minutes: Int) -&gt; Result(Offset, Nil)\n Creates a new offset from a number of minutes.\n \n ## Example\n \n \n offset.new(-65)\n |&gt; result.map(offset.to_string)\n // -&gt; Ok(&quot;-01:05&quot;)\n \nSynonyms:\ntempo/offset.new\ntempo/offset new","url":"tempo/offset.html#new"},{"doc":"tempo/offset","title":"to_string","content":"pub fn to_string(offset: Offset) -&gt; String\n Converts an offset to a string representation.\n \n Will not return &quot;Z&quot; for a zero offset because it is probably not what\n the user wants without the context of a full datetime. Datetime modules\n building on this should cover formatting for Z themselves.\n \n ## Example\n \n \n offset.literal(&quot;-00&quot;)\n |&gt; offset.to_string\n // -&gt; &quot;-00:00&quot;\n \nSynonyms:\ntempo/offset.to_string\ntempo/offset to_string","url":"tempo/offset.html#to_string"},{"doc":"tempo/offset","title":"tempo/offset","content":" Functions to use with the `Offset` type in Tempo. The offset values \n represents the time difference between the current time and UTC time.\n \n ## Example\n \n ```gleam\n import tempo/offset\n \n pub fn get_system_offset() {\n   offset.local()\n   |&gt; offset.to_string\n   // -&gt; &quot;+05:00&quot;\n }\n ```","url":"tempo/offset.html"},{"doc":"tempo/duration","title":"Unit","content":"pub type Unit {\n  YearImprecise\n  Week\n  Day\n  Hour\n  Minute\n  Second\n  Millisecond\n  Microsecond\n}\n\nYearImprecise\n\n\nWeek\n\n\nDay\n\n\nHour\n\n\nMinute\n\n\nSecond\n\n\nMillisecond\n\n\nMicrosecond\n\n\nSynonyms:\ntempo/duration.Unit\ntempo/duration Unit","url":"tempo/duration.html#Unit"},{"doc":"tempo/duration","title":"absolute","content":"pub fn absolute(duration: Duration) -&gt; Duration\n Returns the absolute value of a duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.decrease(by: duration.days(6))\n |&gt; duration.abosulte\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;5 days&quot;\n \nSynonyms:\ntempo/duration.absolute\ntempo/duration absolute","url":"tempo/duration.html#absolute"},{"doc":"tempo/duration","title":"as_days","content":"pub fn as_days(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole days.\nSynonyms:\ntempo/duration.as_days\ntempo/duration as_days","url":"tempo/duration.html#as_days"},{"doc":"tempo/duration","title":"as_days_fractional","content":"pub fn as_days_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional days.\nSynonyms:\ntempo/duration.as_days_fractional\ntempo/duration as_days_fractional","url":"tempo/duration.html#as_days_fractional"},{"doc":"tempo/duration","title":"as_hours","content":"pub fn as_hours(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole hours.\nSynonyms:\ntempo/duration.as_hours\ntempo/duration as_hours","url":"tempo/duration.html#as_hours"},{"doc":"tempo/duration","title":"as_hours_fractional","content":"pub fn as_hours_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional hours.\nSynonyms:\ntempo/duration.as_hours_fractional\ntempo/duration as_hours_fractional","url":"tempo/duration.html#as_hours_fractional"},{"doc":"tempo/duration","title":"as_microseconds","content":"pub fn as_microseconds(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole microseconds.\nSynonyms:\ntempo/duration.as_microseconds\ntempo/duration as_microseconds","url":"tempo/duration.html#as_microseconds"},{"doc":"tempo/duration","title":"as_microseconds_fractional","content":"pub fn as_microseconds_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional microseconds.\n Microseconds are the smallest unit of time that are used in this package.\nSynonyms:\ntempo/duration.as_microseconds_fractional\ntempo/duration as_microseconds_fractional","url":"tempo/duration.html#as_microseconds_fractional"},{"doc":"tempo/duration","title":"as_milliseconds","content":"pub fn as_milliseconds(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole milliseconds.\nSynonyms:\ntempo/duration.as_milliseconds\ntempo/duration as_milliseconds","url":"tempo/duration.html#as_milliseconds"},{"doc":"tempo/duration","title":"as_milliseconds_fractional","content":"pub fn as_milliseconds_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional milliseconds.\nSynonyms:\ntempo/duration.as_milliseconds_fractional\ntempo/duration as_milliseconds_fractional","url":"tempo/duration.html#as_milliseconds_fractional"},{"doc":"tempo/duration","title":"as_minutes","content":"pub fn as_minutes(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole minutes.\nSynonyms:\ntempo/duration.as_minutes\ntempo/duration as_minutes","url":"tempo/duration.html#as_minutes"},{"doc":"tempo/duration","title":"as_minutes_fractional","content":"pub fn as_minutes_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional minutes.\nSynonyms:\ntempo/duration.as_minutes_fractional\ntempo/duration as_minutes_fractional","url":"tempo/duration.html#as_minutes_fractional"},{"doc":"tempo/duration","title":"as_seconds","content":"pub fn as_seconds(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole seconds.\nSynonyms:\ntempo/duration.as_seconds\ntempo/duration as_seconds","url":"tempo/duration.html#as_seconds"},{"doc":"tempo/duration","title":"as_seconds_fractional","content":"pub fn as_seconds_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional seconds.\nSynonyms:\ntempo/duration.as_seconds_fractional\ntempo/duration as_seconds_fractional","url":"tempo/duration.html#as_seconds_fractional"},{"doc":"tempo/duration","title":"as_unit","content":"pub fn as_unit(duration: Duration, unit: Unit) -&gt; Int\n Converts a duration to the specified whole units.\n \n ## Example\n \n \n duration.minutes(1)\n |&gt; duration.as_unit(duration.Second)\n // -&gt; 60\n \nSynonyms:\ntempo/duration.as_unit\ntempo/duration as_unit","url":"tempo/duration.html#as_unit"},{"doc":"tempo/duration","title":"as_unit_fractional","content":"pub fn as_unit_fractional(\n  duration: Duration,\n  unit: Unit,\n) -&gt; Float\n Converts a duration to the specified fractional units.\n \n ## Example\n \n \n duration.days(8)\n |&gt; duration.as_unit_fractional(duration.Week)\n // -&gt; 1.142857143\n \nSynonyms:\ntempo/duration.as_unit_fractional\ntempo/duration as_unit_fractional","url":"tempo/duration.html#as_unit_fractional"},{"doc":"tempo/duration","title":"as_weeks","content":"pub fn as_weeks(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole weeks.\nSynonyms:\ntempo/duration.as_weeks\ntempo/duration as_weeks","url":"tempo/duration.html#as_weeks"},{"doc":"tempo/duration","title":"as_weeks_fractional","content":"pub fn as_weeks_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional weeks.\nSynonyms:\ntempo/duration.as_weeks_fractional\ntempo/duration as_weeks_fractional","url":"tempo/duration.html#as_weeks_fractional"},{"doc":"tempo/duration","title":"as_years_fractional_imprecise","content":"pub fn as_years_fractional_imprecise(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional years, \n assuming a year is 365 days.\n \n ## Example\n \n \n duration.days(375)\n |&gt; duration.as_years_fractional_imprecise\n // -&gt; 1.02739726\n \nSynonyms:\ntempo/duration.as_years_fractional_imprecise\ntempo/duration as_years_fractional_imprecise","url":"tempo/duration.html#as_years_fractional_imprecise"},{"doc":"tempo/duration","title":"as_years_imprecise","content":"pub fn as_years_imprecise(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole years, assuming \n a year is 365 days.\n \n ## Example\n \n \n duration.days(375)\n |&gt; duration.as_years_imprecise\n // -&gt; 1\n \nSynonyms:\ntempo/duration.as_years_imprecise\ntempo/duration as_years_imprecise","url":"tempo/duration.html#as_years_imprecise"},{"doc":"tempo/duration","title":"compare","content":"pub fn compare(a: Duration, to b: Duration) -&gt; Order\n Compares two durations.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.compare(to: duration.days(1))\n // -&gt; order.Eq\n \n \n \n duration.days(1)\n |&gt; duration.compare(to: duration.days(2))\n // -&gt; order.Lt\n \nSynonyms:\ntempo/duration.compare\ntempo/duration compare","url":"tempo/duration.html#compare"},{"doc":"tempo/duration","title":"days","content":"pub fn days(days: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole days.\n \n ## Example\n \n \n duration.days(3)\n |&gt; duration.format_as(duration.Hour, decimals: 0)\n // -&gt; &quot;36 hours&quot;\n \nSynonyms:\ntempo/duration.days\ntempo/duration days","url":"tempo/duration.html#days"},{"doc":"tempo/duration","title":"decrease","content":"pub fn decrease(a: Duration, by b: Duration) -&gt; Duration\n Decreases a duration by the specified duration. If a negative value is \n passed, the duration will be increased.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.decrease(by: duration.days(6))\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;-5 days&quot;\n \n \n \n duration.days(1)\n |&gt; duration.decrease(by: duration.days(6))\n |&gt; duration.abosulte\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;5 days&quot;\n \nSynonyms:\ntempo/duration.decrease\ntempo/duration decrease","url":"tempo/duration.html#decrease"},{"doc":"tempo/duration","title":"format","content":"pub fn format(duration: Duration) -&gt; String\n Formats the duration as a string, inferring the units to use.\n \n ## Example\n \n \n duration.microseconds(172_980_000_000)\n |&gt; duration.format\n // -&gt; &quot;2 days, 0 hours, and 3 minutes&quot;\n \n \n \n duration.seconds(691_332_000_000)\n |&gt; duration.format\n // -&gt; &quot;1 week, 1 day, 0 hours, and 2 minutes&quot;\n \nSynonyms:\ntempo/duration.format\ntempo/duration format","url":"tempo/duration.html#format"},{"doc":"tempo/duration","title":"format_as","content":"pub fn format_as(\n  duration: Duration,\n  unit unit: Unit,\n  decimals decimals: Int,\n) -&gt; String\n Formats the duration as the specified unit with the specified number \n of decimals.\n \n ## Example\n \n \n duration.minutes(1)\n |&gt; duration.format_as(duration.Second, decimals: 3)\n // -&gt; &quot;60.000 minutes&quot;\n \nSynonyms:\ntempo/duration.format_as\ntempo/duration format_as","url":"tempo/duration.html#format_as"},{"doc":"tempo/duration","title":"format_as_many","content":"pub fn format_as_many(\n  duration: Duration,\n  units units: List(Unit),\n  decimals decimals: Int,\n) -&gt; String\n Formats the duration as the specified units, with the last unit having\n the specified number of decimals.\n \n ## Example\n \n \n duration.milliseconds(100_303)\n |&gt; duration.format_as_many(\n   [duration.Minute, duration.Second],\n   decimals: 2,\n )\n // -&gt; &quot;1 minute and 40.30 seconds&quot;\n \nSynonyms:\ntempo/duration.format_as_many\ntempo/duration format_as_many","url":"tempo/duration.html#format_as_many"},{"doc":"tempo/duration","title":"hours","content":"pub fn hours(hours: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole hours.\n \n ## Example\n \n \n duration.hours(13)\n |&gt; duration.format\n // -&gt; &quot;13 hours, 0 minutes, 0.0 seconds&quot;\n \nSynonyms:\ntempo/duration.hours\ntempo/duration hours","url":"tempo/duration.html#hours"},{"doc":"tempo/duration","title":"increase","content":"pub fn increase(a: Duration, by b: Duration) -&gt; Duration\n Increases a duration by the specified duration. If a negative value is \n passed, the duration will be decreased.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.increase(by: duration.days(6))\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;7 days&quot;\n \nSynonyms:\ntempo/duration.increase\ntempo/duration increase","url":"tempo/duration.html#increase"},{"doc":"tempo/duration","title":"inverse","content":"pub fn inverse(duration: Duration) -&gt; Duration\n Returns the inverse of a duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.inverse\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;-1 days&quot;\n \n \nSynonyms:\ntempo/duration.inverse\ntempo/duration inverse","url":"tempo/duration.html#inverse"},{"doc":"tempo/duration","title":"is_equal","content":"pub fn is_equal(a: Duration, to b: Duration) -&gt; Bool\n Checks if a duration is equal to another duration.\n \n ## Example\n \n \n duration.weeks(1)\n |&gt; duration.is_equal(to: duration.days(7))\n // -&gt; True\n \n \n \n duration.days(1)\n |&gt; duration.is_equal(to: duration.days(2))\n // -&gt; False\n \nSynonyms:\ntempo/duration.is_equal\ntempo/duration is_equal","url":"tempo/duration.html#is_equal"},{"doc":"tempo/duration","title":"is_greater","content":"pub fn is_greater(a: Duration, than b: Duration) -&gt; Bool\n Checks if a duration is greater than another duration.\n\n ## Example\n\n \n duration.days(1)\n |&gt; duration.is_greater(than: duration.days(2))\n // -&gt; False\n \n\n \n duration.weeks(1)\n |&gt; duration.is_greater(than: duration.days(1))\n // -&gt; True\n  \nSynonyms:\ntempo/duration.is_greater\ntempo/duration is_greater","url":"tempo/duration.html#is_greater"},{"doc":"tempo/duration","title":"is_greater_or_equal","content":"pub fn is_greater_or_equal(a: Duration, to b: Duration) -&gt; Bool\n Checks if a duration is greater than or equal to another duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.is_greater_or_equal(to: duration.days(2))\n // -&gt; False\n \n \n \n duration.seconds(60)\n |&gt; duration.is_greater_or_equal(to: duration.minutes(1))\n // -&gt; True\n \nSynonyms:\ntempo/duration.is_greater_or_equal\ntempo/duration is_greater_or_equal","url":"tempo/duration.html#is_greater_or_equal"},{"doc":"tempo/duration","title":"is_less","content":"pub fn is_less(a: Duration, than b: Duration) -&gt; Bool\n Checks if a duration is less than another duration.\n\n ## Example\n\n \n duration.days(1)\n |&gt; duration.is_less(than: duration.hours(25))\n // -&gt; True\n \n\n \n duration.days(1)\n |&gt; duration.is_less(than: duration.days(1))\n // -&gt; False\n \nSynonyms:\ntempo/duration.is_less\ntempo/duration is_less","url":"tempo/duration.html#is_less"},{"doc":"tempo/duration","title":"is_less_or_equal","content":"pub fn is_less_or_equal(a: Duration, to b: Duration) -&gt; Bool\n Checks if a duration is less than or equal to another duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.is_less_or_equal(to: duration.days(2))\n // -&gt; True\n \n \n \n duration.days(1)\n |&gt; duration.is_less_or_equal(to: duration.days(1))\n // -&gt; True\n \nSynonyms:\ntempo/duration.is_less_or_equal\ntempo/duration is_less_or_equal","url":"tempo/duration.html#is_less_or_equal"},{"doc":"tempo/duration","title":"is_negative","content":"pub fn is_negative(duration: Duration) -&gt; Bool\n Checks if a duration is negative.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.is_negative\n // -&gt; False\n \n \n \n case \n   time.literal(&quot;13:42:05&quot;)\n   |&gt; time.difference(from: time.literal(&quot;13:42:10&quot;))\n   |&gt; duration.is_negative\n {\n   True -&gt; &quot;we are ahead of time!&quot;\n   False -&gt; &quot;We are either on time or late!&quot;\n }\n \nSynonyms:\ntempo/duration.is_negative\ntempo/duration is_negative","url":"tempo/duration.html#is_negative"},{"doc":"tempo/duration","title":"microseconds","content":"pub fn microseconds(microseconds: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole microseconds.\n \n ## Example\n \n \n duration.milliseconds(1)\n |&gt; duration.increase(by: duration.microseconds(13))\n |&gt; duration.format_as(duration.Microsecond, decimals: 0)\n // -&gt; &quot;113 microseconds&quot;\n \nSynonyms:\ntempo/duration.microseconds\ntempo/duration microseconds","url":"tempo/duration.html#microseconds"},{"doc":"tempo/duration","title":"milliseconds","content":"pub fn milliseconds(milliseconds: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole milliseconds.\n \n ## Example\n \n \n duration.seconds(1)\n |&gt; duration.increase(by: duration.milliseconds(13))\n |&gt; duration.format_as(duration.Millisecond, decimals: 0)\n // -&gt; &quot;113 milliseconds&quot;\n \nSynonyms:\ntempo/duration.milliseconds\ntempo/duration milliseconds","url":"tempo/duration.html#milliseconds"},{"doc":"tempo/duration","title":"minutes","content":"pub fn minutes(minutes: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole minutes.\n \n ## Example\n \n \n duration.minutes(13)\n |&gt; duration.format\n // -&gt; &quot;13 minutes and 0.0 seconds&quot;\n \nSynonyms:\ntempo/duration.minutes\ntempo/duration minutes","url":"tempo/duration.html#minutes"},{"doc":"tempo/duration","title":"new","content":"pub fn new(duration: Int, unit: Unit) -&gt; Duration\n Creates a new duration from the value and unit provided.\n \n ## Example\n \n \n duration.new(100, duration.Millisecond)\n |&gt; duration.as_seconds_fractional\n // -&gt; 0.0000001\n \nSynonyms:\ntempo/duration.new\ntempo/duration new","url":"tempo/duration.html#new"},{"doc":"tempo/duration","title":"seconds","content":"pub fn seconds(seconds: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole seconds.\n \n ## Example\n \n \n duration.minutes(1)\n |&gt; duration.increase(by: duration.seconds(13))\n |&gt; duration.format_as(duration.Second, decimals: 0)\n // -&gt; &quot;73 seconds&quot;\n \nSynonyms:\ntempo/duration.seconds\ntempo/duration seconds","url":"tempo/duration.html#seconds"},{"doc":"tempo/duration","title":"weeks","content":"pub fn weeks(weeks: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole weeks.\n \n ## Example\n \n \n duration.weeks(3)\n |&gt; duration.format\n // -&gt; &quot;3 weeks&quot;\n \nSynonyms:\ntempo/duration.weeks\ntempo/duration weeks","url":"tempo/duration.html#weeks"},{"doc":"tempo/duration","title":"years_imprecise","content":"pub fn years_imprecise(years: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole years,\n assuming a year is 365 days.\n\n ## Example\n \n \n duration.years_imprecise(1)\n |&gt; duration.format\n // -&gt; &quot;1 ~year&quot;\n \nSynonyms:\ntempo/duration.years_imprecise\ntempo/duration years_imprecise","url":"tempo/duration.html#years_imprecise"},{"doc":"tempo/duration","title":"tempo/duration","content":" Functions to use with the `Duration` type in Tempo.\n \n ## Example\n \n ```gleam\n import gleam/io\n import tempo/duration\n import tempo/time\n \n pub fn main() {\n   time.literal(&quot;01:42:11&quot;)\n   |&gt; time.since(time.literal(&quot;00:00:01&quot;))\n   |&gt; duration.format\n   // -&gt; &quot;1 hour, 42 minutes, 10 seconds&quot;\n }\n ```","url":"tempo/duration.html"},{"doc":"tempo/time","title":"Boundary","content":"pub type Boundary {\n  Boundary(time: tempo.Time, inclusive: Bool)\n}\n\nBoundary(time: tempo.Time, inclusive: Bool)\n\n\nSynonyms:\ntempo/time.Boundary\ntempo/time Boundary","url":"tempo/time.html#Boundary"},{"doc":"tempo/time","title":"end_of_day","content":"pub const end_of_day: Time\n The end of the last second of the day.\n \n ## Example\n \n \n time.end_of_day\n |&gt; time.to_string\n // &quot;24:00:00.000000&quot;\n \n \n \n tempo.DateTime(date.literal(&quot;2024-06-21&quot;), time.end_of_day, offset.utc)\n |&gt; datetime.to_string\n // &quot;2024-06-21T24:00:00.000000Z&quot;\n \nSynonyms:\ntempo/time.end_of_day\ntempo/time end_of_day","url":"tempo/time.html#end_of_day"},{"doc":"tempo/time","title":"start_of_day","content":"pub const start_of_day: Time\n The first second of the day.\n \n ## Example\n \n \n time.start_of_day\n |&gt; time.to_string\n // &quot;00:00:00.000000&quot;\n \n \n \n tempo.DateTime(date.literal(&quot;2024-06-21&quot;), time.start_of_day, offset.utc)\n |&gt; datetime.to_string\n // &quot;2024-06-21T00:00:00.000000Z&quot;\n \nSynonyms:\ntempo/time.start_of_day\ntempo/time start_of_day","url":"tempo/time.html#start_of_day"},{"doc":"tempo/time","title":"add","content":"pub fn add(a: Time, duration b: Duration) -&gt; Time\n Adds a duration to a time.\n \n ## Example\n \n \n time.literal(&quot;08:42:53&quot;)\n |&gt; time.add(duration.mintues(36))\n // -&gt; time.literal(&quot;09:18:53&quot;)\n \nSynonyms:\ntempo/time.add\ntempo/time add","url":"tempo/time.html#add"},{"doc":"tempo/time","title":"compare","content":"pub fn compare(a: Time, to b: Time) -&gt; Order\n Compares two time values.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.compare(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; order.Eq\n \n \n \n time.literal(&quot;15:32:01&quot;)\n |&gt; time.compare(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; order.Gt\n \n \n \n time.literal(&quot;13:10:11&quot;)\n |&gt; time.compare(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; order.Lt\n \nSynonyms:\ntempo/time.compare\ntempo/time compare","url":"tempo/time.html#compare"},{"doc":"tempo/time","title":"describe_out_of_bounds_error","content":"pub fn describe_out_of_bounds_error(\n  error: TimeOutOfBoundsError,\n) -&gt; String\n Converts a time out of bounds error to a human readable error message.\n \n ## Example\n \n \n time.new(23, 59, 60)\n |&gt; snag.map_error(with: time.describe_out_of_bounds_error)\n // -&gt; snag.error(&quot;Second out of bounds in time: 60&quot;)\nSynonyms:\ntempo/time.describe_out_of_bounds_error\ntempo/time describe_out_of_bounds_error","url":"tempo/time.html#describe_out_of_bounds_error"},{"doc":"tempo/time","title":"describe_parse_error","content":"pub fn describe_parse_error(error: TimeParseError) -&gt; String\n Converts a time parse error to a human readable error message.\n \n ## Example\n \n \n time.parse(&quot;13 42 11&quot;, &quot;HH:mm:ss&quot;)\n |&gt; snag.map_error(with: time.describe_parse_error)\n // -&gt; snag.error(&quot;Invalid time format: &quot;13 42 11&quot;&quot;)\nSynonyms:\ntempo/time.describe_parse_error\ntempo/time describe_parse_error","url":"tempo/time.html#describe_parse_error"},{"doc":"tempo/time","title":"difference","content":"pub fn difference(from a: Time, to b: Time) -&gt; Duration\n Gets the difference between two times as a duration. Always prefer using\n `duration.start_monotonic` and `duration.stop_monotonic` to record live \n time passing, as it is more precise.\n \n ## Example\n \n \n time.literal(&quot;23:42:11.435&quot;)\n |&gt; time.difference(from: time.literal(&quot;23:42:09.743&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 1692\n \n \n \n time.literal(&quot;13:30:11&quot;)\n |&gt; time.difference(from: time.literal(&quot;13:55:13&quot;))\n |&gt; duration.as_minutes\n // -&gt; -25\n \nSynonyms:\ntempo/time.difference\ntempo/time difference","url":"tempo/time.html#difference"},{"doc":"tempo/time","title":"difference_abs","content":"pub fn difference_abs(a: Time, from b: Time) -&gt; Duration\n Gets the absolute difference between two times as a duration.\n \n ## Example\n \n \n time.literal(&quot;23:42:11.435&quot;)\n |&gt; time.difference(from: time.literal(&quot;23:42:09.743&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 1692\n \n \n \n time.literal(&quot;13:30:11&quot;)\n |&gt; time.difference(from: time.literal(&quot;13:55:13&quot;))\n |&gt; duration.as_minutes\n // -&gt; 25\n \nSynonyms:\ntempo/time.difference_abs\ntempo/time difference_abs","url":"tempo/time.html#difference_abs"},{"doc":"tempo/time","title":"format","content":"pub fn format(time: Time, in format: TimeFormat) -&gt; String\n Formats a time value using the provided format.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.format(tempo.ISO8601TimeMilli)\n // -&gt; &quot;13:42:11.000&quot;\n \n \n \n time.literal(&quot;13:42:11.314&quot;)\n |&gt; time.format(&quot;h:mm A&quot;)\n // -&gt; &quot;1:42 PM&quot;\n \n \n  \n time.literal(&quot;09:02:01.014920202&quot;)\n |&gt; time.format(&quot;HH:mm:ss SSS SSSS SSSSS&quot;)\n // -&gt; &quot;09:02:01 014 014920 014920202&quot;\n \n \n \n naive_datetime.literal(&quot;13:02:01&quot;)\n |&gt; naive_datetime.format(&quot;H HH h hh m mm s ss a A [An ant]&quot;)\n // -------------------&gt; &quot;13 13 1 01 2 02 1 01 pm PM An ant&quot;\n \nSynonyms:\ntempo/time.format\ntempo/time format","url":"tempo/time.html#format"},{"doc":"tempo/time","title":"from_duration","content":"pub fn from_duration(duration: Duration) -&gt; Time\n Converts a duration to the equivalent time of day, assuming the \n duration epoch is &quot;00:00:00&quot;. Durations longer than 24 hours will be \n wrapped to fit within a 24 hour representation.\n \n ## Example\n \n \n duration.seconds(58)\n |&gt; time.from_duration\n |&gt; time.to_second_precision\n |&gt; time.to_string\n // -&gt; &quot;00:00:58&quot;\n \n \n \n duration.minutes(17)\n |&gt; time.from_duration\n |&gt; time.to_string\n // -&gt; &quot;00:17:00.000000000&quot;\n \n \n \n duration.hours(25)\n |&gt; time.from_duration\n |&gt; time.to_string\n // -&gt; &quot;01:00:00.000000000&quot;\n \n \n \n duration.microseconds(-3_000_000)\n |&gt; time.from_duration\n |&gt; time.to_string\n // -&gt; &quot;23:59:57.000000&quot;\n \nSynonyms:\ntempo/time.from_duration\ntempo/time from_duration","url":"tempo/time.html#from_duration"},{"doc":"tempo/time","title":"from_string","content":"pub fn from_string(\n  time_str: String,\n) -&gt; Result(Time, TimeParseError)\n Converts a string to a time value. Accepted formats are `hh:mm:ss.s`, \n `hhmmss.s`, `hh:mm:ss`, `hhmmss`, `hh:mm`, or `hhmm`.\n \n ## Example\n \n \n time.from_string(&quot;00:00:00.000000300&quot;)\n // -&gt; Ok(time.literal(&quot;00:00:00.000000300&quot;))\n \n \n \n time.from_string(&quot;34:54:16&quot;)\n // -&gt; Error(tempo_error.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.from_string\ntempo/time from_string","url":"tempo/time.html#from_string"},{"doc":"tempo/time","title":"from_tuple","content":"pub fn from_tuple(\n  time: #(Int, Int, Int),\n) -&gt; Result(Time, TimeOutOfBoundsError)\n Converts a tuple of hours, minutes, and seconds to a time value. Useful \n for using with another time library.\n \n ## Example\n \n \n #(13, 42, 11)\n |&gt; time.from_tuple\n // -&gt; time.literal(&quot;13:42:11&quot;)\n \nSynonyms:\ntempo/time.from_tuple\ntempo/time from_tuple","url":"tempo/time.html#from_tuple"},{"doc":"tempo/time","title":"from_tuple_microsecond","content":"pub fn from_tuple_microsecond(\n  time: #(Int, Int, Int, Int),\n) -&gt; Result(Time, TimeOutOfBoundsError)\n Converts a tuple of hours, minutes, seconds, and microseconds to a time \n value. Useful for using with another time library.\n \n ## Example\n \n \n #(13, 42, 11, 872000)\n |&gt; time.from_tuple_microsecond\n // -&gt; time.literal(&quot;13:42:11.872&quot;)\n \nSynonyms:\ntempo/time.from_tuple_microsecond\ntempo/time from_tuple_microsecond","url":"tempo/time.html#from_tuple_microsecond"},{"doc":"tempo/time","title":"get_hour","content":"pub fn get_hour(time: Time) -&gt; Int\n Gets the hour value of a time.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.get_hour\n // -&gt; 13\n \nSynonyms:\ntempo/time.get_hour\ntempo/time get_hour","url":"tempo/time.html#get_hour"},{"doc":"tempo/time","title":"get_microsecond","content":"pub fn get_microsecond(time: Time) -&gt; Int\n Gets the microsecond value of a time.\n \n ## Example\n \n \n time.literal(&quot;13:42:11.123&quot;)\n |&gt; time.get_microsecond\n // -&gt; 123000\n \nSynonyms:\ntempo/time.get_microsecond\ntempo/time get_microsecond","url":"tempo/time.html#get_microsecond"},{"doc":"tempo/time","title":"get_minute","content":"pub fn get_minute(time: Time) -&gt; Int\n Gets the minute value of a time.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.get_minute\n // -&gt; 42\n \nSynonyms:\ntempo/time.get_minute\ntempo/time get_minute","url":"tempo/time.html#get_minute"},{"doc":"tempo/time","title":"get_second","content":"pub fn get_second(time: Time) -&gt; Int\n Gets the second value of a time.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.get_second\n // -&gt; 11\n \nSynonyms:\ntempo/time.get_second\ntempo/time get_second","url":"tempo/time.html#get_second"},{"doc":"tempo/time","title":"is_between","content":"pub fn is_between(\n  time: Time,\n  start: Boundary,\n  and end: Boundary,\n) -&gt; Bool\n Checks if a time is between two boundaries.\n \n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_between(\n     Boundary(time.literal(&quot;05:00:00&quot;), inclusive: True), \n     and: Boundary(time.literal(&quot;15:00:00&quot;), inclusive: False),\n   )\n // -&gt; True\n \nSynonyms:\ntempo/time.is_between\ntempo/time is_between","url":"tempo/time.html#is_between"},{"doc":"tempo/time","title":"is_earlier","content":"pub fn is_earlier(a: Time, than b: Time) -&gt; Bool\n Checks if the first time is earlier than the second time.\n\n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier(than: time.literal(&quot;13:42:12&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier(than: time.literal(&quot;13:42:11&quot;))\n // -&gt; False\n \n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_earlier(than: time.literal(&quot;07:42:11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_earlier\ntempo/time is_earlier","url":"tempo/time.html#is_earlier"},{"doc":"tempo/time","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(a: Time, to b: Time) -&gt; Bool\n Checks if the first time is earlier or equal to the second time.\n\n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier_or_equal(to: time.literal(&quot;13:42:12&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier_or_equal(to: time.literal(&quot;13:42:11.000&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_earlier_or_equal(to: time.literal(&quot;07:42:12&quot;))\n // -&gt; False\nSynonyms:\ntempo/time.is_earlier_or_equal\ntempo/time is_earlier_or_equal","url":"tempo/time.html#is_earlier_or_equal"},{"doc":"tempo/time","title":"is_equal","content":"pub fn is_equal(a: Time, to b: Time) -&gt; Bool\n Checks if the first time is equal to the second time.\n\n ## Example\n\n \n time.literal(&quot;13:42:11.000&quot;)\n |&gt; time.is_equal(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:42:11.002&quot;)\n |&gt; time.is_equal(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_equal\ntempo/time is_equal","url":"tempo/time.html#is_equal"},{"doc":"tempo/time","title":"is_later","content":"pub fn is_later(a: Time, than b: Time) -&gt; Bool\n Checks if the first time is later than the second time.\n\n ## Example\n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_later(than: time.literal(&quot;07:42:11&quot;))\n // -&gt; True\n \n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_later(than: time.literal(&quot;13:42:12&quot;))\n // -&gt; False\n \n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_later(than: time.literal(&quot;13:42:11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_later\ntempo/time is_later","url":"tempo/time.html#is_later"},{"doc":"tempo/time","title":"is_later_or_equal","content":"pub fn is_later_or_equal(a: Time, to b: Time) -&gt; Bool\n Checks if the first time is earlier or equal to the second time.\n\n ## Example\n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_later_or_equal(to: time.literal(&quot;07:42:12&quot;))\n // -&gt; True\n\n \n time.literal(&quot;13:42&quot;)\n |&gt; time.is_later_or_equal(to: time.literal(&quot;13:42:00.000&quot;))\n // -&gt; True\n \n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_later_or_equal(to: time.literal(&quot;13:42:12&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_later_or_equal\ntempo/time is_later_or_equal","url":"tempo/time.html#is_later_or_equal"},{"doc":"tempo/time","title":"is_outside","content":"pub fn is_outside(\n  time: Time,\n  start: Boundary,\n  and end: Boundary,\n) -&gt; Bool\n Checks if a time is outside of two boundaries.\n \n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_outside(\n     time.Boundary(time.literal(&quot;05:00:00&quot;), inclusive: True), \n     and: time.Boundary(time.literal(&quot;15:00:00&quot;), inclusive: False),\n   )\n // -&gt; False\n \nSynonyms:\ntempo/time.is_outside\ntempo/time is_outside","url":"tempo/time.html#is_outside"},{"doc":"tempo/time","title":"left_in_day","content":"pub fn left_in_day(time: Time) -&gt; Time\n Converts a time to the equivalent time left in the day.\n\n ## Example\n\n \n time.literal(&quot;23:59:03&quot;) |&gt; time.left_in_day\n // -&gt; time.literal(&quot;00:00:57&quot;)\n \n\n \n time.literal(&quot;08:05:20&quot;) |&gt; time.left_in_day\n // -&gt; time.literal(&quot;15:54:40&quot;)\n \nSynonyms:\ntempo/time.left_in_day\ntempo/time left_in_day","url":"tempo/time.html#left_in_day"},{"doc":"tempo/time","title":"literal","content":"pub fn literal(time: String) -&gt; Time\n Creates a new time value from a string literal, but will panic if\n the string is invalid. Accepted formats are\n `hh:mm:ss.s`, `hhmmss.s`, `hh:mm:ss`, `hhmmss`, `hh:mm`, or `hhmm`.\n \n Useful for declaring time literals that you know are valid within your \n program.\n \n ## Example\n \n \n case \n   time.now_local() \n   |&gt; time.is_later(than: time.literal(&quot;11:50:00&quot;)) \n { \n   True -&gt; &quot;We are late!&quot;\n   False -&gt; &quot;No rush :)&quot;\n }\n \nSynonyms:\ntempo/time.literal\ntempo/time literal","url":"tempo/time.html#literal"},{"doc":"tempo/time","title":"new","content":"pub fn new(\n  hour: Int,\n  minute: Int,\n  second: Int,\n) -&gt; Result(Time, TimeOutOfBoundsError)\n Creates a new time value with second precision.\n \n ## Example\n \n \n time.new(13, 42, 11)\n // -&gt; Ok(time.literal(&quot;13:42:11&quot;))\n \n \n \n time.new(53, 42, 61)\n // -&gt; Error(tempo_error.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.new\ntempo/time new","url":"tempo/time.html#new"},{"doc":"tempo/time","title":"new_micro","content":"pub fn new_micro(\n  hour: Int,\n  minute: Int,\n  second: Int,\n  microsecond: Int,\n) -&gt; Result(Time, TimeOutOfBoundsError)\n Creates a new time value with microsecond precision.\n \n ## Example\n \n \n time.new_micro(13, 42, 11, 20)\n // -&gt; Ok(time.literal(&quot;13:42:11.000020&quot;))\n \n \n \n time.new_micro(13, 42, 11, 200_000)\n // -&gt; Ok(time.literal(&quot;13:42:11.200000&quot;))\n \n \n \n time.new_micro(13, 42, 11, 7_500_000)\n |&gt; result.map_error(time.describe_out_of_bounds_error)\n // -&gt; Error(&quot;Subsecond value out of bounds in time: 13:42:11.7500000&quot;)\n \nSynonyms:\ntempo/time.new_micro\ntempo/time new_micro","url":"tempo/time.html#new_micro"},{"doc":"tempo/time","title":"new_milli","content":"pub fn new_milli(\n  hour: Int,\n  minute: Int,\n  second: Int,\n  millisecond: Int,\n) -&gt; Result(Time, TimeOutOfBoundsError)\n Creates a new time value with millisecond precision.\n \n ## Example\n \n \n time.new_milli(13, 42, 11, 20)\n // -&gt; Ok(time.literal(&quot;13:42:11.020&quot;))\n \n \n \n time.new_milli(13, 42, 11, 200)\n // -&gt; Ok(time.literal(&quot;13:42:11.200&quot;))\n \n \n \n time.new_milli(13, 42, 11, 7_500)\n // -&gt; Error(tempo_error.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.new_milli\ntempo/time new_milli","url":"tempo/time.html#new_milli"},{"doc":"tempo/time","title":"parse","content":"pub fn parse(\n  str: String,\n  in format: TimeFormat,\n) -&gt; Result(Time, TimeParseError)\n Parses a time string in the provided format. Always prefer using\n this over `parse_any`. All parsed formats must have an hour and a second.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] HH&quot;.\n \n Available directives: H (hour), HH (two-digit hour), h (12-hour clock hour), hh \n (two-digit 12-hour clock hour), m (minute), mm (two-digit minute),\n s (second), ss (two-digit second), SSS (millisecond), SSSS (microsecond), \n A (AM/PM), a (am/pm),\n \n ## Example\n \n \n time.parse(&quot;2024/06/08, 13:42:11&quot;, &quot;YYYY/MM/DD&quot;)\n // -&gt; Ok(time.literal(&quot;13:42:11&quot;))\n \n \n \n time.parse(&quot;January 13, 2024&quot;, &quot;MMMM DD, YYYY&quot;)\n |&gt; result.map_error(time.describe_parse_error)\n // -&gt; Error(&quot;Invlid time format: January 13, 2024&quot;)\n \n \n \n time.parse(&quot;Hi! 12 2 am&quot;, &quot;[Hi!] h m a&quot;)\n // -&gt; Ok(time.literal(&quot;00:02:00&quot;))\n \nSynonyms:\ntempo/time.parse\ntempo/time parse","url":"tempo/time.html#parse"},{"doc":"tempo/time","title":"parse_any","content":"pub fn parse_any(str: String) -&gt; Result(Time, TimeParseError)\n Tries to parse a given date string without a known format. It will not \n parse two digit years and will assume the month always comes before the \n day in a date. Will leave off any time offset values present.\n \n ## Example\n \n \n time.parse_any(&quot;2024.06.21 01:32 PM -04:00&quot;)\n // -&gt; Ok(time.literal(&quot;13:32:00&quot;))\n \n \n \n time.parse_any(&quot;2024.06.21&quot;)\n // -&gt; Error(tempo.ParseMissingTime)\n \nSynonyms:\ntempo/time.parse_any\ntempo/time parse_any","url":"tempo/time.html#parse_any"},{"doc":"tempo/time","title":"since","content":"pub fn since(time time: Time, since since: Time) -&gt; Duration\n Returns a duration representing the time since the first time to the \n given time.\n \n ## Example\n \n \n time.literal(&quot;23:54:00&quot;)\n |&gt; time.since(time.literal(&quot;13:30:04&quot;))\n |&gt; duration.as_hours\n // -&gt; 10\n \n \n \n time.literal(&quot;12:30:54&quot;)\n |&gt; time.since(time.literal(&quot;22:00:00&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 0\n \nSynonyms:\ntempo/time.since\ntempo/time since","url":"tempo/time.html#since"},{"doc":"tempo/time","title":"subtract","content":"pub fn subtract(a: Time, duration b: Duration) -&gt; Time\n Subtracts a duration from a time.\n \n ## Example\n \n \n time.literal(&quot;13:42:02&quot;)\n |&gt; time.subtract(duration.hours(2))\n // -&gt; time.literal(&quot;11:42:02&quot;)\n \nSynonyms:\ntempo/time.subtract\ntempo/time subtract","url":"tempo/time.html#subtract"},{"doc":"tempo/time","title":"to_duration","content":"pub fn to_duration(time: Time) -&gt; Duration\n Converts a time to duration, assuming the duration epoch is &quot;00:00:00&quot;.\n \n ## Example\n \n \n time.literal(&quot;00:00:00.000300&quot;)\n |&gt; time.to_duration\n |&gt; duration.as_microseconds\n // -&gt; 300\n \n\n \n time.literal(&quot;00:03:06&quot;)\n |&gt; time.to_duration \n |&gt; duration.as_milliseconds\n // -&gt; 186_000\n \nSynonyms:\ntempo/time.to_duration\ntempo/time to_duration","url":"tempo/time.html#to_duration"},{"doc":"tempo/time","title":"to_string","content":"pub fn to_string(time: Time) -&gt; String\n Converts a time value to a string in the format `hh:mm:ss.s` with \n millisecond precision. If a different precision is needed, use the `format` \n function.\n \n ## Example\n \n \n time.to_string(my_time)\n // -&gt; &quot;21:53:03.534&quot;\n \nSynonyms:\ntempo/time.to_string\ntempo/time to_string","url":"tempo/time.html#to_string"},{"doc":"tempo/time","title":"to_tuple","content":"pub fn to_tuple(time: Time) -&gt; #(Int, Int, Int)\n Returns a time value as a tuple of hours, minutes, and seconds. Useful \n for using with another time library.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.to_tuple\n // -&gt; #(13, 42, 11)\n \nSynonyms:\ntempo/time.to_tuple\ntempo/time to_tuple","url":"tempo/time.html#to_tuple"},{"doc":"tempo/time","title":"to_tuple_microsecond","content":"pub fn to_tuple_microsecond(time: Time) -&gt; #(Int, Int, Int, Int)\n Returns a time value as a tuple of hours, minutes, seconds, and microseconds. \n Useful for using with another time library.\n \n ## Example\n \n \n time.literal(&quot;13:42:11.872&quot;)\n |&gt; time.to_tuple_microsecond\n // -&gt; #(13, 42, 11, 872000)\n \nSynonyms:\ntempo/time.to_tuple_microsecond\ntempo/time to_tuple_microsecond","url":"tempo/time.html#to_tuple_microsecond"},{"doc":"tempo/time","title":"until","content":"pub fn until(time: Time, until: Time) -&gt; Duration\n Returns a duration representing the time left from the first time \n until a given time. \n \n ## Example\n \n \n time.literal(&quot;23:54:00&quot;)\n |&gt; time.until(time.literal(&quot;23:59:04&quot;))\n |&gt; duration.as_seconds\n // -&gt; 304\n \n \n \n time.literal(&quot;23:59:03&quot;)\n |&gt; time.until(time.literal(&quot;22:00:00&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 0\n \nSynonyms:\ntempo/time.until\ntempo/time until","url":"tempo/time.html#until"},{"doc":"tempo/time","title":"tempo/time","content":" Functions to use with the `Time` type in Tempo. The time values are wall\n time values unless explicitly stated otherwise.\n \n ## Examples\n \n ```gleam\n import tempo/time\n \n pub fn is_past_5pm() {\n   tempo.is_time_later(than: time.literal(&quot;17:00&quot;))\n }\n ```\n \n ```gleam\n import tempo/time\n \n pub fn get_enthusiastic_time() {\n   time.literal(&quot;13:42&quot;)\n   |&gt; time.format(tempo.CustomTime(\n     &quot;[The hour is:] HH, [wow! And even better the minute is:] mm!&quot;\n   ))\n   // -&gt; &quot;The hour is: 13, wow! And even better the minute is: 42!&quot;\n }\n ```","url":"tempo/time.html"},{"doc":"tempo/naive_datetime","title":"add","content":"pub fn add(\n  datetime: NaiveDateTime,\n  duration duration_to_add: Duration,\n) -&gt; NaiveDateTime\n Adds a duration to a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.add(duration.minutes(3))\n // -&gt; naive_datetime.literal(&quot;2024-06-21T23:20:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.add\ntempo/naive_datetime add","url":"tempo/naive_datetime.html#add"},{"doc":"tempo/naive_datetime","title":"as_local","content":"pub fn as_local(datetime: NaiveDateTime) -&gt; DateTime\n Sets a naive datetime&#39;s offset to the host&#39;s local offset, leaving the \n date and time unchanged while returning a datetime value. \n Alias for `set_offset(naive_datetime, offset.local())`.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.as_local\n // -&gt; datetime.literal(&quot;2024-06-21T23:17:00+01:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.as_local\ntempo/naive_datetime as_local","url":"tempo/naive_datetime.html#as_local"},{"doc":"tempo/naive_datetime","title":"as_period","content":"pub fn as_period(\n  start start: NaiveDateTime,\n  end end: NaiveDateTime,\n) -&gt; Period\n Creates a period between two naive datetimes. The specified start and end\n datetimes will be swapped if the start datetime is later than the end\n datetime.\n \n ## Examples\n \n \n naive_datetime.to_period(\n   start: naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;)\n   end: naive_datetime.literal(&quot;2024-06-16T01:16:12&quot;),\n )\n |&gt; period.as_days\n // -&gt; 3\n \n \n \n naive_datetime.to_period(\n   start: naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-16T01:18:12&quot;),\n )\n |&gt; period.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/naive_datetime.as_period\ntempo/naive_datetime as_period","url":"tempo/naive_datetime.html#as_period"},{"doc":"tempo/naive_datetime","title":"as_utc","content":"pub fn as_utc(datetime: NaiveDateTime) -&gt; DateTime\n Sets a naive datetime&#39;s offset to UTC, leaving the date and time unchanged\n while returning a datetime value. \n Alias for `set_offset(naive_datetime, offset.utc)`.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.as_utc\n // -&gt; datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n \nSynonyms:\ntempo/naive_datetime.as_utc\ntempo/naive_datetime as_utc","url":"tempo/naive_datetime.html#as_utc"},{"doc":"tempo/naive_datetime","title":"compare","content":"pub fn compare(a: NaiveDateTime, to b: NaiveDateTime) -&gt; Order\n Compares two naive datetimes.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.compare(to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;))\n // -&gt; order.Eq\n \n \n \n naive_datetime.literal(&quot;2023-05-11T13:15:00&quot;)\n |&gt; naive_datetime.compare(to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;))\n // -&gt; order.Lt\n \nSynonyms:\ntempo/naive_datetime.compare\ntempo/naive_datetime compare","url":"tempo/naive_datetime.html#compare"},{"doc":"tempo/naive_datetime","title":"describe_parse_error","content":"pub fn describe_parse_error(\n  error: NaiveDateTimeParseError,\n) -&gt; String\n Converts a naive datetime parse error to a human readable error message.\n \n ## Example\n \n \n naive_datetime.parse(&quot;2024 06 21 23:17:00&quot;)\n |&gt; snag.map_error(with: naive_datetime.describe_parse_error)\n // -&gt; snag.error(&quot;Invalid date format in naive datetime: 2024 06 21 23:17:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.describe_parse_error\ntempo/naive_datetime describe_parse_error","url":"tempo/naive_datetime.html#describe_parse_error"},{"doc":"tempo/naive_datetime","title":"difference","content":"pub fn difference(\n  from a: NaiveDateTime,\n  to b: NaiveDateTime,\n) -&gt; Duration\n Returns the difference between two naive datetimes as a duration.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-16T01:16:12&quot;)\n |&gt; naive_datetime.difference(\n   naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;),\n )\n |&gt; duration.as_days\n // -&gt; 3\n \n \n \n naive_datetime.literal(&quot;2024-06-16T01:18:12&quot;)\n |&gt; naive_datetime.difference(\n   naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;),\n )\n |&gt; duration.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/naive_datetime.difference\ntempo/naive_datetime difference","url":"tempo/naive_datetime.html#difference"},{"doc":"tempo/naive_datetime","title":"drop_time","content":"pub fn drop_time(datetime: NaiveDateTime) -&gt; NaiveDateTime\n Drops the time of a naive datetime, setting it to zero.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-13T23:17:00&quot;)\n |&gt; naive_datetime.drop_time\n // -&gt; datetime.literal(&quot;2024-06-13T00:00:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.drop_time\ntempo/naive_datetime drop_time","url":"tempo/naive_datetime.html#drop_time"},{"doc":"tempo/naive_datetime","title":"format","content":"pub fn format(\n  naive_datetime: NaiveDateTime,\n  in format: NaiveDateTimeFormat,\n) -&gt; String\n Formats a naive datetime value using the provided format string.\n Implements the same formatting directives as the great Day.js \n library: https://day.js.org/docs/en/display/format.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] YYYY&quot;.\n \n Available directives: YY (two-digit year), YYYY (four-digit year), M (month), \n MM (two-digit month), MMM (short month name), MMMM (full month name), \n D (day of the month), DD (two-digit day of the month), d (day of the week), \n dd (min day of the week), ddd (short day of week), dddd (full day of the week), \n H (hour), HH (two-digit hour), h (12-hour clock hour), hh \n (two-digit 12-hour clock hour), m (minute), mm (two-digit minute),\n s (second), ss (two-digit second), SSS (millisecond), SSSS (microsecond), \n A (AM/PM), a (am/pm).\n \n ## Example\n \n \n naive_datetime.literal(&quot;2024-06-21T13:42:11.314&quot;)\n |&gt; naive_datetime.format(&quot;ddd @ h:mm A&quot;)\n // -&gt; &quot;Fri @ 1:42 PM&quot;\n \n \n \n naive_datetime.literal(&quot;2024-06-03T09:02:01&quot;)\n |&gt; naive_datetime.format(&quot;YY YYYY M MM MMM MMMM D DD d dd ddd&quot;)\n // --------------------&gt; &quot;24 2024 6 06 Jun June 3 03 1 Mo Mon&quot;\n \n \n  \n naive_datetime.literal(&quot;2024-06-03T09:02:01.014920202&quot;)\n |&gt; naive_datetime.format(&quot;dddd SSS SSSS SSSSS&quot;)\n // -&gt; &quot;Monday 014 014920 014920202&quot;\n \n \n \n naive_datetime.literal(&quot;2024-06-03T13:02:01&quot;)\n |&gt; naive_datetime.format(&quot;H HH h hh m mm s ss a A [An ant]&quot;)\n // -------------------&gt; &quot;13 13 1 01 2 02 1 01 pm PM An ant&quot;\n \nSynonyms:\ntempo/naive_datetime.format\ntempo/naive_datetime format","url":"tempo/naive_datetime.html#format"},{"doc":"tempo/naive_datetime","title":"from_string","content":"pub fn from_string(\n  datetime: String,\n) -&gt; Result(NaiveDateTime, NaiveDateTimeParseError)\n Parses a naive datetime string in the format `YYYY-MM-DDThh:mm:ss.s`,\n `YYYY-MM-DD hh:mm:ss.s`, `YYYY-MM-DD`, `YYYY-M-D`, `YYYY/MM/DD`, \n `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`, `YYYY_M_D`, \n `YYYY MM DD`, `YYYY M D`, or `YYYYMMDD`.\n \n ## Examples\n \n naive_datetime.from_string(&quot;20240612&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-06-12T00:00:00&quot;))\n \n \n \n naive_datetime.from_string(&quot;2024-06-21 23:17:00&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;))\n \n \n \n naive_datetime.from_string(&quot;24-06-12|23:17:00&quot;)\n // -&gt; Error(tempo.NaiveDateTimeInvalidFormat)\n \nSynonyms:\ntempo/naive_datetime.from_string\ntempo/naive_datetime from_string","url":"tempo/naive_datetime.html#from_string"},{"doc":"tempo/naive_datetime","title":"get_date","content":"pub fn get_date(datetime: NaiveDateTime) -&gt; Date\n Gets the date of a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.get_date\n // -&gt; date.literal(&quot;2024-06-21&quot;)\n \nSynonyms:\ntempo/naive_datetime.get_date\ntempo/naive_datetime get_date","url":"tempo/naive_datetime.html#get_date"},{"doc":"tempo/naive_datetime","title":"get_time","content":"pub fn get_time(datetime: NaiveDateTime) -&gt; Time\n Gets the time of a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.get_time\n // -&gt; time.literal(&quot;23:17:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.get_time\ntempo/naive_datetime get_time","url":"tempo/naive_datetime.html#get_time"},{"doc":"tempo/naive_datetime","title":"is_earlier","content":"pub fn is_earlier(\n  a: NaiveDateTime,\n  than b: NaiveDateTime,\n) -&gt; Bool\n Checks if the first naive datetime is earlier than the second naive \n datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier(\n   than: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; False\n \n \n \n naive_datetime.literal(&quot;2013-06-12T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier(\n   than: naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/naive_datetime.is_earlier\ntempo/naive_datetime is_earlier","url":"tempo/naive_datetime.html#is_earlier"},{"doc":"tempo/naive_datetime","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(\n  a: NaiveDateTime,\n  to b: NaiveDateTime,\n) -&gt; Bool\n Checks if the first naive datetime is earlier or equal to the second naive \n datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-08-12T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-12T00:00:00&quot;),\n )\n // -&gt; False\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/naive_datetime.is_earlier_or_equal\ntempo/naive_datetime is_earlier_or_equal","url":"tempo/naive_datetime.html#is_earlier_or_equal"},{"doc":"tempo/naive_datetime","title":"is_equal","content":"pub fn is_equal(a: NaiveDateTime, to b: NaiveDateTime) -&gt; Bool\n Checks if the first naive datetime is equal to the second naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; True\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:01&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/naive_datetime.is_equal\ntempo/naive_datetime is_equal","url":"tempo/naive_datetime.html#is_equal"},{"doc":"tempo/naive_datetime","title":"is_later","content":"pub fn is_later(a: NaiveDateTime, than b: NaiveDateTime) -&gt; Bool\n Checks if the first naive datetime is later than the second naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_later(\n   than: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; False\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_later(\n   than: naive_datetime.literal(&quot;2022-04-12T00:00:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/naive_datetime.is_later\ntempo/naive_datetime is_later","url":"tempo/naive_datetime.html#is_later"},{"doc":"tempo/naive_datetime","title":"is_later_or_equal","content":"pub fn is_later_or_equal(\n  a: NaiveDateTime,\n  to b: NaiveDateTime,\n) -&gt; Bool\n Checks if the first naive datetime is later or equal to the second naive \n datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_later_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; True\n \n \n \n naive_datetime.literal(&quot;2022-04-12T00:00:00&quot;)\n |&gt; naive_datetime.is_later_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/naive_datetime.is_later_or_equal\ntempo/naive_datetime is_later_or_equal","url":"tempo/naive_datetime.html#is_later_or_equal"},{"doc":"tempo/naive_datetime","title":"literal","content":"pub fn literal(naive_datetime: String) -&gt; NaiveDateTime\n Creates a new naive datetime value from a string literal, but will panic \n if the string is invalid.\n \n Useful for declaring date literals that you know are valid within your  \n program.\n\n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:04:00.009&quot;)\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-21T23:04:00.009&quot;\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:04:00.009-04:00&quot;)\n // panic\n \nSynonyms:\ntempo/naive_datetime.literal\ntempo/naive_datetime literal","url":"tempo/naive_datetime.html#literal"},{"doc":"tempo/naive_datetime","title":"new","content":"pub fn new(date: Date, time: Time) -&gt; NaiveDateTime\n Creates a new naive datetime from a date and time value.\n \n ## Examples\n \n \n naive_datetime.new(\n   date.literal(&quot;2024-06-21&quot;), \n   time.literal(&quot;23:04:00.009&quot;),\n )\n // -&gt; naive_datetime.literal(&quot;2024-06-21T23:04:00.009&quot;)\n \nSynonyms:\ntempo/naive_datetime.new\ntempo/naive_datetime new","url":"tempo/naive_datetime.html#new"},{"doc":"tempo/naive_datetime","title":"parse","content":"pub fn parse(\n  str: String,\n  in format: NaiveDateTimeFormat,\n) -&gt; Result(NaiveDateTime, NaiveDateTimeParseError)\n Parses a naive datetime string in the provided format. Always prefer using\n this over `parse_any`. All parsed formats must have all parts of a naive\n datetime (date and time). Use the other modules for parsing lesser\n date time values.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] YYYY&quot;.\n \n Available directives: YY (two-digit year), YYYY (four-digit year), M (month), \n MM (two-digit month), MMM (short month name), MMMM (full month name), \n D (day of the month), DD (two-digit day of the month),\n H (hour), HH (two-digit hour), h (12-hour clock hour), hh \n (two-digit 12-hour clock hour), m (minute), mm (two-digit minute),\n s (second), ss (two-digit second), SSS (millisecond), SSSS (microsecond), \n A (AM/PM), a (am/pm).\n \n ## Example\n \n \n naive_datetime.parse(&quot;2024/06/08, 13:42:11&quot;, &quot;YYYY/MM/DD, HH:mm:ss&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-06-08T13:42:11&quot;))\n \n \n \n naive_datetime.parse(&quot;January 13, 2024. 3:42:11&quot;, &quot;MMMM DD, YYYY. H:mm:ss&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-01-13T03:42:11&quot;))\n \n \n \n naive_datetime.parse(&quot;Hi! 2024 11 13 12 2 am&quot;, &quot;[Hi!] YYYY M D h m a&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-11-13T00:02:00&quot;))\n \nSynonyms:\ntempo/naive_datetime.parse\ntempo/naive_datetime parse","url":"tempo/naive_datetime.html#parse"},{"doc":"tempo/naive_datetime","title":"parse_any","content":"pub fn parse_any(\n  str: String,\n) -&gt; Result(NaiveDateTime, NaiveDateTimeParseError)\n Tries to parse a given date string without a known format. It will not \n parse two digit years and will assume the month always comes before the \n day in a date. Will leave off any time offset values present.\n \n ## Example\n \n \n naive_datetime.parse_any(&quot;2024.06.21 01:32 PM -04:00&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-06-21T13:32:00&quot;))\n \n \n \n naive_datetime.parse_any(&quot;2024.06.21&quot;)\n // -&gt; Error(tempo.ParseMissingTime)\n \nSynonyms:\ntempo/naive_datetime.parse_any\ntempo/naive_datetime parse_any","url":"tempo/naive_datetime.html#parse_any"},{"doc":"tempo/naive_datetime","title":"set_offset","content":"pub fn set_offset(\n  datetime: NaiveDateTime,\n  offset: Offset,\n) -&gt; DateTime\n Sets a naive datetime&#39;s offset to the provided offset, leaving the date and\n time unchanged while returning a datetime value. \n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.set_offset(offset.literal(&quot;+10:00&quot;))\n // -&gt; datetime.literal(&quot;2024-06-21T23:17:00+10:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.set_offset\ntempo/naive_datetime set_offset","url":"tempo/naive_datetime.html#set_offset"},{"doc":"tempo/naive_datetime","title":"subtract","content":"pub fn subtract(\n  datetime: NaiveDateTime,\n  duration duration_to_subtract: Duration,\n) -&gt; NaiveDateTime\n Subtracts a duration from a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;)\n |&gt; naive_datetime.subtract(duration.days(3))\n // -&gt; naive_datetime.literal(&quot;2024-06-09T23:17:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.subtract\ntempo/naive_datetime subtract","url":"tempo/naive_datetime.html#subtract"},{"doc":"tempo/naive_datetime","title":"time_left_in_day","content":"pub fn time_left_in_day(naive_datetime: NaiveDateTime) -&gt; Time\n Gets the time left in the day.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n\n \n naive_datetime.literal(&quot;2015-06-30T23:59:03&quot;)\n |&gt; naive_datetime |&gt; tempo.naive_datetime_get_time_left_in_day\n // -&gt; time.literal(&quot;00:00:57&quot;)\n \n \n \n naive_datetime.literal(&quot;2024-06-18T08:05:20&quot;)\n |&gt; naive_datetime |&gt; tempo.naive_datetime_get_time_left_in_day\n // -&gt; time.literal(&quot;15:54:40&quot;)\n \nSynonyms:\ntempo/naive_datetime.time_left_in_day\ntempo/naive_datetime time_left_in_day","url":"tempo/naive_datetime.html#time_left_in_day"},{"doc":"tempo/naive_datetime","title":"to_string","content":"pub fn to_string(datetime: NaiveDateTime) -&gt; String\n Returns a string representation of a naive datetime value in the ISO 8601\n format with millisecond precision. If a different precision is needed, \n use the `format` function. \n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-21T23:17:00.000&quot;\n \nSynonyms:\ntempo/naive_datetime.to_string\ntempo/naive_datetime to_string","url":"tempo/naive_datetime.html#to_string"},{"doc":"tempo/naive_datetime","title":"to_tuple","content":"pub fn to_tuple(\n  naive_datetime: NaiveDateTime,\n) -&gt; #(#(Int, Int, Int), #(Int, Int, Int))\n Returns a tuple of the date and time values in the format used in Erlang.\n \n ## Example\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:07&quot;)\n |&gt; naive_datetime.to_tuple\n // -&gt; #(#(2024, 6, 21), #(23, 17, 7))\n \nSynonyms:\ntempo/naive_datetime.to_tuple\ntempo/naive_datetime to_tuple","url":"tempo/naive_datetime.html#to_tuple"},{"doc":"tempo/naive_datetime","title":"tempo/naive_datetime","content":" Functions to use with the `NaiveDateTime` type in Tempo. Naive datetimes\n are datetime values without an offset or timezone value.\n \n ## Example\n \n ```gleam\n import tempo/naive_datetime\n import tempo/date\n import tempo/time\n \n pub fn get_date_and_time() {\n   naive_datetime.now_local()\n   |&gt; naive_datetime.to_string\n   // -&gt; &quot;2024-06-21T13:42:11&quot;\n }","url":"tempo/naive_datetime.html"},{"doc":"tempo/datetime","title":"UncertainConversion","content":"pub type UncertainConversion(a) {\n  Precise(a)\n  Imprecise(a)\n}\n The result of an uncertain conversion. Since this package does not track\n timezone offsets, it uses the host system&#39;s offset to convert to local\n time. If the datetime being converted to local time is of a different\n day than the current one, the offset value provided by the host may\n not be accurate (and could be accurate by up to the amount the offset \n changes throughout the year). To account for this, when converting to \n local time, a precise value is returned when the datetime being converted\n is in th current date, while an imprecise value is returned when it is\n on any other date. This allows the application logic to handle the \n two cases differently: some applications may only need to convert to \n local time on the current date or may only need generic time \n representations, while other applications may need precise conversions \n for arbitrary dates. More notes on how to plug time zones into this\n package to aviod uncertain conversions can be found in the README.\nPrecise(a)\n\n\nImprecise(a)\n\n\nSynonyms:\ntempo/datetime.UncertainConversion\ntempo/datetime UncertainConversion","url":"tempo/datetime.html#UncertainConversion"},{"doc":"tempo/datetime","title":"accept_imprecision","content":"pub fn accept_imprecision(conv: UncertainConversion(a)) -&gt; a\n Accepts either a precise or imprecise value of an uncertain conversion.\n Useful for pipelines.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n |&gt; datetime.to_local\n |&gt; tempo.accept_imprecision\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-21T19:17:00-04:00&quot;\n \nSynonyms:\ntempo/datetime.accept_imprecision\ntempo/datetime accept_imprecision","url":"tempo/datetime.html#accept_imprecision"},{"doc":"tempo/datetime","title":"add","content":"pub fn add(\n  datetime: DateTime,\n  duration duration_to_add: Duration,\n) -&gt; DateTime\n Adds a duration to a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n |&gt; datetime.add(duration |&gt; tempo.offset_get_minutes(3))\n // -&gt; datetime.literal(&quot;2024-06-12T23:20:00Z&quot;)\n \nSynonyms:\ntempo/datetime.add\ntempo/datetime add","url":"tempo/datetime.html#add"},{"doc":"tempo/datetime","title":"apply_offset","content":"pub fn apply_offset(datetime: DateTime) -&gt; NaiveDateTime\n Applies the offset of a datetime to the date and time values, resulting\n in a new naive datetime value that represents the original datetime in \n UTC time.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T05:36:11.195-04:00&quot;)\n |&gt; datetime.apply_offset\n // -&gt; naive_datetime.literal(&quot;2024-06-21T09:36:11.195&quot;)\n \nSynonyms:\ntempo/datetime.apply_offset\ntempo/datetime apply_offset","url":"tempo/datetime.html#apply_offset"},{"doc":"tempo/datetime","title":"as_period","content":"pub fn as_period(\n  start start: DateTime,\n  end end: DateTime,\n) -&gt; Period\n Creates a period between two datetimes, where the start and end times are\n the equivalent UTC times of the provided datetimes. The specified start \n and end datetimes will be swapped if the start datetime is later than the \n end datetime.\n \n ## Examples\n \n \n datetime.to_period(\n   start: datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n   end: datetime.literal(&quot;2024-06-16T01:16:12Z&quot;),\n )\n |&gt; period.as_days\n // -&gt; 3\n \n \n \n datetime.to_period(\n   start: datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n   end: datetime.literal(&quot;2024-06-16T01:18:12Z&quot;),\n )\n |&gt; period.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/datetime.as_period\ntempo/datetime as_period","url":"tempo/datetime.html#as_period"},{"doc":"tempo/datetime","title":"compare","content":"pub fn compare(a: DateTime, to b: DateTime) -&gt; Order\n Compares two datetimes.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.compare(to: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;))\n // -&gt; order.Eq\n \n \n \n datetime.literal(&quot;2023-05-11T13:30:00-04:00&quot;)\n |&gt; datetime.compare(to: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;))\n // -&gt; order.Lt\n \n \n \n datetime.literal(&quot;2024-06-12T23:47:00+09:05&quot;)\n |&gt; datetime.compare(to: datetime.literal(&quot;2022-04-12T00:00:00&quot;))\n // -&gt; order.Gt\n \nSynonyms:\ntempo/datetime.compare\ntempo/datetime compare","url":"tempo/datetime.html#compare"},{"doc":"tempo/datetime","title":"describe_parse_error","content":"pub fn describe_parse_error(error: DateTimeParseError) -&gt; String\n Converts a datetime parse error to a human readable error message.\n \n ## Example\n \n \n datetime.parse(&quot;13:42:11.314-04:00&quot;, &quot;YYYY-MM-DDTHH:mm:ss.SSSZ&quot;)\n |&gt; snag.map_error(with: datetime.describe_parse_error)\n // -&gt; snag.error(&quot;Invalid date format in datetime: 13:42:11.314-04:00&quot;)\nSynonyms:\ntempo/datetime.describe_parse_error\ntempo/datetime describe_parse_error","url":"tempo/datetime.html#describe_parse_error"},{"doc":"tempo/datetime","title":"difference","content":"pub fn difference(from a: DateTime, to b: DateTime) -&gt; Duration\n Returns the difference between two datetimes as a duration between their\n equivalent UTC times.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n |&gt; datetime.difference(\n   from: datetime.literal(&quot;2024-06-16T01:16:12Z&quot;),\n )\n |&gt; duration.as_days\n // -&gt; 3\n \n \n \n datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n |&gt; datetime.difference(\n   from: datetime.literal(&quot;2024-06-16T01:18:12Z&quot;),\n )\n |&gt; duration.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/datetime.difference\ntempo/datetime difference","url":"tempo/datetime.html#difference"},{"doc":"tempo/datetime","title":"drop_offset","content":"pub fn drop_offset(datetime: DateTime) -&gt; NaiveDateTime\n Drops the time of a datetime, leaving the date and time values unchanged.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T13:42:11.195Z&quot;)\n |&gt; datetime.drop_offset\n // -&gt; naive_datetime.literal(&quot;2024-06-13T13:42:11&quot;)\n \nSynonyms:\ntempo/datetime.drop_offset\ntempo/datetime drop_offset","url":"tempo/datetime.html#drop_offset"},{"doc":"tempo/datetime","title":"drop_time","content":"pub fn drop_time(datetime: DateTime) -&gt; DateTime\n Drops the time of a datetime, leaving the date value unchanged.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-18T13:42:11.195Z&quot;)\n |&gt; datetime.drop_time\n // -&gt; naive_datetime.literal(&quot;2024-06-18T00:00:00Z&quot;)\n \nSynonyms:\ntempo/datetime.drop_time\ntempo/datetime drop_time","url":"tempo/datetime.html#drop_time"},{"doc":"tempo/datetime","title":"error_on_imprecision","content":"pub fn error_on_imprecision(\n  conv: UncertainConversion(a),\n) -&gt; Result(a, Nil)\n Either returns a precise value or an error from an uncertain conversion.\n Useful for pipelines. \n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n |&gt; datetime.to_local\n |&gt; tempo.error_on_imprecision\n |&gt; result.try(do_important_precise_task)\n \nSynonyms:\ntempo/datetime.error_on_imprecision\ntempo/datetime error_on_imprecision","url":"tempo/datetime.html#error_on_imprecision"},{"doc":"tempo/datetime","title":"format","content":"pub fn format(\n  datetime: DateTime,\n  in format: DateTimeFormat,\n) -&gt; String\n Formats a datetime value into a string using the provided format.\n \n ## Examples\n \n \n datetime.literal(tempo.Custom(&quot;2024-06-21T13:42:11.314-04:00&quot;))\n |&gt; datetime.format(&quot;ddd @ h:mm A (z)&quot;)\n // -&gt; &quot;Fri @ 1:42 PM (-04)&quot;\n \n \n \n datetime.literal(&quot;2024-06-03T09:02:01-04:00&quot;)\n |&gt; datetime.format(tempo.Custom(&quot;YY YYYY M MM MMM MMMM D DD d dd ddd&quot;))\n // -----------:---------------&gt; &quot;24 2024 6 06 Jun June 3 03 1 Mo Mon&quot;\n \n \n  \n datetime.literal(&quot;2024-06-03T09:02:01.014920202-00:00&quot;)\n |&gt; datetime.format(tempo.Custom(&quot;dddd SSS SSSS SSSSS Z ZZ z&quot;))\n // -&gt; &quot;Monday 014 014920 014920202 -00:00 -0000 Z&quot;\n \n \n \n datetime.literal(&quot;2024-06-03T13:02:01-04:00&quot;)\n |&gt; datetime.format(tempo.Custom(&quot;H HH h hh m mm s ss a A [An ant]&quot;))\n // --------------------------&gt; &quot;13 13 1 01 2 02 1 01 pm PM An ant&quot;\n \nSynonyms:\ntempo/datetime.format\ntempo/datetime format","url":"tempo/datetime.html#format"},{"doc":"tempo/datetime","title":"from_dynamic_string","content":"pub fn from_dynamic_string(\n  dynamic_string: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid datetime string, and returns the\n datetime if it is.\n \n ## Examples\n \n \n dynamic.from(&quot;2024-06-13T13:42:11.195Z&quot;)\n |&gt; datetime.from_dynamic_string\n // -&gt; Ok(datetime.literal(&quot;2024-06-13T13:42:11.195Z&quot;))\n \n \n \n dynamic.from(&quot;24-06-13,13:42:11.195&quot;)\n |&gt; datetime.from_dynamic_string\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;tempo.DateTime&quot;,\n //     found: &quot;Invalid format: 24-06-13,13:42:11.195&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_string\ntempo/datetime from_dynamic_string","url":"tempo/datetime.html#from_dynamic_string"},{"doc":"tempo/datetime","title":"from_dynamic_unix_micro_utc","content":"pub fn from_dynamic_unix_micro_utc(\n  dynamic_ts: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid unix timestamp in microseconds, and \n returns the datetime if it is.\n \n ## Examples\n \n \n dynamic.from(1_718_629_314_334_734)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Ok(datetime.literal(&quot;2024-06-17T13:01:54.334734Z&quot;))\n \n \n \n dynamic.from(&quot;hello&quot;)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;Int&quot;,\n //     found: &quot;String&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_unix_micro_utc\ntempo/datetime from_dynamic_unix_micro_utc","url":"tempo/datetime.html#from_dynamic_unix_micro_utc"},{"doc":"tempo/datetime","title":"from_dynamic_unix_milli_utc","content":"pub fn from_dynamic_unix_milli_utc(\n  dynamic_ts: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid unix timestamp in milliseconds, and \n returns the datetime if it is.\n \n ## Examples\n \n \n dynamic.from(1_718_629_314_334)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Ok(datetime.literal(&quot;2024-06-17T13:01:54.334Z&quot;))\n \n \n \n dynamic.from(&quot;hello&quot;)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;Int&quot;,\n //     found: &quot;String&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_unix_milli_utc\ntempo/datetime from_dynamic_unix_milli_utc","url":"tempo/datetime.html#from_dynamic_unix_milli_utc"},{"doc":"tempo/datetime","title":"from_dynamic_unix_utc","content":"pub fn from_dynamic_unix_utc(\n  dynamic_ts: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid unix timestamp in seconds, and \n returns the datetime if it is.\n \n ## Examples\n \n \n dynamic.from(1_718_629_314)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Ok(datetime.literal(&quot;2024-06-17T13:01:54Z&quot;))\n \n \n \n dynamic.from(&quot;hello&quot;)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;Int&quot;,\n //     found: &quot;String&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_unix_utc\ntempo/datetime from_dynamic_unix_utc","url":"tempo/datetime.html#from_dynamic_unix_utc"},{"doc":"tempo/datetime","title":"from_string","content":"pub fn from_string(\n  datetime: String,\n) -&gt; Result(DateTime, DateTimeParseError)\n Parses a datetime string in the format `YYYY-MM-DDThh:mm:ss.sTZD`,\n `YYYYMMDDThhmmss.sTZD`, `YYYY-MM-DD hh:mm:ss.sTZD`,\n `YYYYMMDD hhmmss.sTZD`, `YYYY-MM-DD`, `YYYY-M-D`, `YYYY/MM/DD`, \n `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`, `YYYY_M_D`, \n `YYYY MM DD`, `YYYY M D`, or `YYYYMMDD`.\n \n ## Examples\n \n \n datetime.from_string(&quot;20240613T230400.009+00:00&quot;)\n // -&gt; datetime.literal(&quot;2024-06-13T23:04:00.009Z&quot;)\n \nSynonyms:\ntempo/datetime.from_string\ntempo/datetime from_string","url":"tempo/datetime.html#from_string"},{"doc":"tempo/datetime","title":"from_unix_micro","content":"pub fn from_unix_micro(unix_ts: Int) -&gt; DateTime\n Returns the UTC datetime of a unix timestamp in microseconds.\n \n ## Examples\n \n \n datetime.from_unix_micro(1_718_629_314_334_734)\n // -&gt; datetime.literal(&quot;2024-06-17T13:01:54.334734Z&quot;)\n \nSynonyms:\ntempo/datetime.from_unix_micro\ntempo/datetime from_unix_micro","url":"tempo/datetime.html#from_unix_micro"},{"doc":"tempo/datetime","title":"from_unix_milli","content":"pub fn from_unix_milli(unix_ts: Int) -&gt; DateTime\n Returns the UTC datetime of a unix timestamp in milliseconds.\n \n ## Examples\n \n \n datetime.from_unix_milli(1_718_629_314_334)\n // -&gt; datetime.literal(&quot;2024-06-17T13:01:54.334Z&quot;)\n \nSynonyms:\ntempo/datetime.from_unix_milli\ntempo/datetime from_unix_milli","url":"tempo/datetime.html#from_unix_milli"},{"doc":"tempo/datetime","title":"from_unix_seconds","content":"pub fn from_unix_seconds(unix_ts: Int) -&gt; DateTime\n Returns the UTC datetime of a unix timestamp.\n \n ## Examples\n \n \n datetime.from_unix_seconds(1_718_829_191)\n // -&gt; datetime.literal(&quot;2024-06-17T12:59:51Z&quot;)\n \nSynonyms:\ntempo/datetime.from_unix_seconds\ntempo/datetime from_unix_seconds","url":"tempo/datetime.html#from_unix_seconds"},{"doc":"tempo/datetime","title":"get_date","content":"pub fn get_date(datetime: DateTime) -&gt; Date\n Gets the date of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T13:42:11.195Z&quot;)\n |&gt; datetime.get_date\n // -&gt; date.literal(&quot;2024-06-21&quot;)\n \nSynonyms:\ntempo/datetime.get_date\ntempo/datetime get_date","url":"tempo/datetime.html#get_date"},{"doc":"tempo/datetime","title":"get_offset","content":"pub fn get_offset(datetime: DateTime) -&gt; Offset\n Gets the offset of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-12T13:42:11.195-04:00&quot;)\n |&gt; datetime.get_offset\n // -&gt; offset.literal(&quot;+04:00&quot;)\n \nSynonyms:\ntempo/datetime.get_offset\ntempo/datetime get_offset","url":"tempo/datetime.html#get_offset"},{"doc":"tempo/datetime","title":"get_time","content":"pub fn get_time(datetime: DateTime) -&gt; Time\n Gets the time of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T13:42:11.195Z&quot;)\n |&gt; datetime.get_time\n // -&gt; time.literal(&quot;13:42:11.195&quot;)\n \nSynonyms:\ntempo/datetime.get_time\ntempo/datetime get_time","url":"tempo/datetime.html#get_time"},{"doc":"tempo/datetime","title":"get_timezone_name","content":"pub fn get_timezone_name(datetime: DateTime) -&gt; Option(String)\n Gets the name of the timezone the datetime is in.\n \n ## Example\n \n \n datetime.literal(&quot;2024-06-21T06:30:02.334Z&quot;)\n |&gt; datetime.get_timezone_name\n // -&gt; None\n \n \n \n import gtz\n let assert Ok(tz) = gtz.timezone(&quot;Europe/London&quot;)\n datetime.to_timezone(my_datetime, tz)\n |&gt; datetime.get_timezone_name\n // -&gt; Some(&quot;Europe/London&quot;)\n \nSynonyms:\ntempo/datetime.get_timezone_name\ntempo/datetime get_timezone_name","url":"tempo/datetime.html#get_timezone_name"},{"doc":"tempo/datetime","title":"is_earlier","content":"pub fn is_earlier(a: DateTime, than b: DateTime) -&gt; Bool\n Checks if the first datetime is earlier than the second datetime.\n\n ## Examples\n\n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.is_earlier(\n   than: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; False\n \n\n \n datetime.literal(&quot;2023-05-11T13:30:00-04:00&quot;)\n |&gt; datetime.is_earlier(\n   than: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/datetime.is_earlier\ntempo/datetime is_earlier","url":"tempo/datetime.html#is_earlier"},{"doc":"tempo/datetime","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(a: DateTime, to b: DateTime) -&gt; Bool\n Checks if the first datetime is earlier or equal to the second datetime.\n \n ## Examples\n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.is_earlier_or_equal(\n   to: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; True\n \n \n \n datetime.literal(&quot;2024-07-15T23:40:00-04:00&quot;)\n |&gt; datetime.is_earlier_or_equal(\n   to: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/datetime.is_earlier_or_equal\ntempo/datetime is_earlier_or_equal","url":"tempo/datetime.html#is_earlier_or_equal"},{"doc":"tempo/datetime","title":"is_equal","content":"pub fn is_equal(a: DateTime, to b: DateTime) -&gt; Bool\n Checks if the first datetime is equal to the second datetime.\n \n ## Examples\n \n datetime.literal(&quot;2024-06-21T09:44:00Z&quot;)\n |&gt; datetime.is_equal(\n   to: datetime.literal(&quot;2024-06-21T05:44:00-04:00&quot;),\n )\n // -&gt; True\n \n \n \n datetime.literal(&quot;2024-06-21T09:44:00Z&quot;)\n |&gt; datetime.is_equal(\n   to: datetime.literal(&quot;2024-06-21T09:44:00.045Z&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/datetime.is_equal\ntempo/datetime is_equal","url":"tempo/datetime.html#is_equal"},{"doc":"tempo/datetime","title":"is_later","content":"pub fn is_later(a: DateTime, than b: DateTime) -&gt; Bool\n Checks if the first datetime is later than the second datetime.\n\n ## Examples\n\n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.is_later(\n   than: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; False\n \n\n \n datetime.literal(&quot;2023-05-11T13:00:00+04:00&quot;)\n |&gt; datetime.is_later(\n   than: datetime.literal(&quot;2023-05-11T13:15:00.534Z&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/datetime.is_later\ntempo/datetime is_later","url":"tempo/datetime.html#is_later"},{"doc":"tempo/datetime","title":"is_later_or_equal","content":"pub fn is_later_or_equal(a: DateTime, to b: DateTime) -&gt; Bool\n Checks if the first datetime is later or equal to the second datetime.\n \n ## Examples\n \n datetime.literal(&quot;2016-01-11T03:47:00+09:05&quot;)\n |&gt; datetime.is_later_or_equal(\n   to: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; False\n \n \n \n datetime.literal(&quot;2024-07-15T23:40:00-04:00&quot;)\n |&gt; datetime.is_later_or_equal(\n   to: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/datetime.is_later_or_equal\ntempo/datetime is_later_or_equal","url":"tempo/datetime.html#is_later_or_equal"},{"doc":"tempo/datetime","title":"literal","content":"pub fn literal(datetime: String) -&gt; DateTime\n Create a new datetime value from a string literal, but will panic if\n the string is invalid. Accepted formats are `YYYY-MM-DDThh:mm:ss.sTZD` or\n `YYYYMMDDThhmmss.sTZD`\n \n Useful for declaring datetime literals that you know are valid within your  \n program.\n\n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T23:04:00.009+10:00&quot;)\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-13T23:04:00.009+10:00&quot;\n \nSynonyms:\ntempo/datetime.literal\ntempo/datetime literal","url":"tempo/datetime.html#literal"},{"doc":"tempo/datetime","title":"new","content":"pub fn new(\n  date date: Date,\n  time time: Time,\n  offset offset: Offset,\n) -&gt; DateTime\n Create a new datetime from a date, time, and offset.\n \n ## Examples\n \n \n datetime.new(\n   date.literal(&quot;2024-06-13&quot;), \n   time.literal(&quot;23:04:00.009&quot;),\n   offset.literal(&quot;+10:00&quot;),\n )\n // -&gt; datetime.literal(&quot;2024-06-13T23:04:00.009+10:00&quot;)\n \nSynonyms:\ntempo/datetime.new\ntempo/datetime new","url":"tempo/datetime.html#new"},{"doc":"tempo/datetime","title":"parse","content":"pub fn parse(\n  str: String,\n  in format: DateTimeFormat,\n) -&gt; Result(DateTime, DateTimeParseError)\n Parses a datetime string in the provided format. Always prefer using\n this over `parse_any`. All parsed formats must have all parts of a\n datetime (date, time, offset). Use the other modules for parsing lesser\n date time values.\n \n Values can be escaped by putting brackets around them, like &quot;[Hello!] YYYY&quot;.\n \n Available directives: YY (two-digit year), YYYY (four-digit year), M (month), \n MM (two-digit month), MMM (short month name), MMMM (full month name), \n D (day of the month), DD (two-digit day of the month),\n H (hour), HH (two-digit hour), h (12-hour clock hour), hh \n (two-digit 12-hour clock hour), m (minute), mm (two-digit minute),\n s (second), ss (two-digit second), SSS (millisecond), SSSS (microsecond), \n Z (offset from UTC), ZZ (offset from UTC with no &quot;:&quot;),\n z (short offset from UTC &quot;-04&quot;, &quot;Z&quot;), A (AM/PM), a (am/pm).\n \n ## Example\n \n \n datetime.parse(&quot;2024/06/08, 13:42:11, -04:00&quot;, &quot;YYYY/MM/DD, HH:mm:ss, Z&quot;)\n // -&gt; Ok(datetime.literal(&quot;2024-06-08T13:42:11-04&quot;))\n \n \n \n datetime.parse(&quot;January 13, 2024. 3:42:11Z&quot;, &quot;MMMM DD, YYYY. H:mm:ssz&quot;)\n // -&gt; Ok(datetime.literal(&quot;2024-01-13T03:42:11Z&quot;))\n \n \n \n datetime.parse(&quot;Hi! 2024 11 13 12 2 am Z&quot;, &quot;[Hi!] YYYY M D h m a z&quot;)\n // -&gt; Ok(datetime.literal(&quot;2024-11-13T00:02:00Z&quot;))\n \nSynonyms:\ntempo/datetime.parse\ntempo/datetime parse","url":"tempo/datetime.html#parse"},{"doc":"tempo/datetime","title":"parse_any","content":"pub fn parse_any(\n  str: String,\n) -&gt; Result(DateTime, DateTimeParseError)\n Tries to parse a given date string without a known format. It will not \n parse two digit years and will assume the month always comes before the \n day in a date.\n \n ## Example\n \n \n parse_any.parse_any(&quot;2024.06.21 01:32 PM -0400&quot;)\n // -&gt; Ok(datetime.literal(&quot;2024-06-21T13:32:00-04:00&quot;))\n \n \n \n parse_any.parse_any(&quot;2024.06.21 01:32 PM&quot;)\n // -&gt; Error(tempo.ParseMissingOffset)\n \nSynonyms:\ntempo/datetime.parse_any\ntempo/datetime parse_any","url":"tempo/datetime.html#parse_any"},{"doc":"tempo/datetime","title":"subtract","content":"pub fn subtract(\n  datetime: DateTime,\n  duration duration_to_subtract: Duration,\n) -&gt; DateTime\n Subtracts a duration from a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n |&gt; datetime.subtract(duration.days(3))\n // -&gt; datetime.literal(&quot;2024-06-18T23:17:00Z&quot;)\n \nSynonyms:\ntempo/datetime.subtract\ntempo/datetime subtract","url":"tempo/datetime.html#subtract"},{"doc":"tempo/datetime","title":"time_left_in_day","content":"pub fn time_left_in_day(datetime: DateTime) -&gt; Time\n Gets the time left in the day.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n\n \n naive_datetime.literal(&quot;2015-06-30T23:59:03Z&quot;)\n |&gt; naive_datetime.time_left_in_day\n // -&gt; time.literal(&quot;00:00:57&quot;)\n \n \n \n naive_datetime.literal(&quot;2024-06-18T08:05:20-04:00&quot;)\n |&gt; naive_datetime.time_left_in_day\n // -&gt; time.literal(&quot;15:54:40&quot;)\n \nSynonyms:\ntempo/datetime.time_left_in_day\ntempo/datetime time_left_in_day","url":"tempo/datetime.html#time_left_in_day"},{"doc":"tempo/datetime","title":"to_local","content":"pub fn to_local(\n  datetime: DateTime,\n) -&gt; UncertainConversion(DateTime)\n Converts a datetime to the equivalent local datetime. The return value\n indicates if the conversion was precise or imprecise. Use pattern\n matching or the `tempo.accept_imprecision` function to handle the two cases.\n \n Conversion is based on the host&#39;s current offset. If the date of the\n supplied datetime matches the date of the host, then we can apply the\n current host&#39;s offset to get the local time safely, resulting in a precise\n conversion. If the date does not match the host&#39;s, then we can not be \n sure the current offset is still applicable, and will perform an \n imprecise conversion. The imprecise conversion can be inaccurate to the\n degree the local offset changes throughout the year. For example, in \n North America where Daylight Savings Time is observed with a one-hour\n time shift, the imprecise conversion can be off by up to an hour depending\n on the time of year.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T09:57:11.195Z&quot;)\n |&gt; datetime.to_local\n // -&gt; tempo.Precise(datetime.literal(&quot;2024-06-21T05:57:11.195-04:00&quot;))\n \n \n \n datetime.literal(&quot;1998-08-23T09:57:11.195Z&quot;)\n |&gt; datetime.to_local\n // -&gt; tempo.Imprecise(datetime.literal(&quot;1998-08-23T05:57:11.195-04:00&quot;))\n \nSynonyms:\ntempo/datetime.to_local\ntempo/datetime to_local","url":"tempo/datetime.html#to_local"},{"doc":"tempo/datetime","title":"to_local_date","content":"pub fn to_local_date(\n  datetime: DateTime,\n) -&gt; UncertainConversion(Date)\n Converts a datetime to the equivalent local time. The return value\n indicates if the conversion was precise or imprecise. Use pattern\n matching or the `tempo.accept_imprecision` function to handle the two cases.\n \n Conversion is based on the host&#39;s current offset. If the date of the\n supplied datetime matches the date of the host, then we can apply the\n current host&#39;s offset to get the local time safely, resulting in a precise\n conversion. If the date does not match the host&#39;s, then we can not be \n sure the current offset is still applicable, and will perform an \n imprecise conversion. The imprecise conversion can be inaccurate to the\n degree the local offset changes throughout the year. For example, in \n North America where Daylight Savings Time is observed with a one-hour\n time shift, the imprecise conversion can be off by up to an hour depending\n on the time of year.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-19T01:35:11.195Z&quot;)\n |&gt; datetime.to_local_date\n // -&gt; tempo.Precise(date.literal(&quot;2024-06-18&quot;))\n \n \n \n datetime.literal(&quot;1998-08-23T01:57:11.195Z&quot;)\n |&gt; datetime.to_local_date\n // -&gt; tempo.Imprecise(date.literal(&quot;1998-08-22&quot;))\n \nSynonyms:\ntempo/datetime.to_local_date\ntempo/datetime to_local_date","url":"tempo/datetime.html#to_local_date"},{"doc":"tempo/datetime","title":"to_local_time","content":"pub fn to_local_time(\n  datetime: DateTime,\n) -&gt; UncertainConversion(Time)\n Converts a datetime to the equivalent local time. The return value\n indicates if the conversion was precise or imprecise. Use pattern\n matching or the `tempo.accept_imprecision` function to handle the two cases.\n \n Conversion is based on the host&#39;s current offset. If the date of the\n supplied datetime matches the date of the host, then we can apply the\n current host&#39;s offset to get the local time safely, resulting in a precise\n conversion. If the date does not match the host&#39;s, then we can not be \n sure the current offset is still applicable, and will perform an \n imprecise conversion. The imprecise conversion can be inaccurate to the\n degree the local offset changes throughout the year. For example, in \n North America where Daylight Savings Time is observed with a one-hour\n time shift, the imprecise conversion can be off by up to an hour depending\n on the time of year.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T09:57:11.195Z&quot;)\n |&gt; datetime.to_local_time\n // -&gt; tempo.Precise(time.literal(&quot;05:57:11.195&quot;))\n \n \n \n datetime.literal(&quot;1998-08-23T09:57:11.195Z&quot;)\n |&gt; datetime.to_local_time\n // -&gt; tempo.Imprecise(time.literal(&quot;05:57:11.195&quot;))\n \nSynonyms:\ntempo/datetime.to_local_time\ntempo/datetime to_local_time","url":"tempo/datetime.html#to_local_time"},{"doc":"tempo/datetime","title":"to_offset","content":"pub fn to_offset(datetime: DateTime, offset: Offset) -&gt; DateTime\n Converts a datetime to the equivalent time in an offset.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T05:36:11.195-04:00&quot;)\n |&gt; datetime.to_offset(offset.literal(&quot;+10:00&quot;))\n // -&gt; datetime.literal(&quot;2024-06-21T19:36:11.195+10:00&quot;)\n \nSynonyms:\ntempo/datetime.to_offset\ntempo/datetime to_offset","url":"tempo/datetime.html#to_offset"},{"doc":"tempo/datetime","title":"to_string","content":"pub fn to_string(datetime: DateTime) -&gt; String\n Returns a string representation of a datetime value in the ISO 8601\n format with millisecond precision. If a different precision is needed, \n use the `format` function. If serializing to send outside of Gleam and then\n parse back into a datetime value, use the `serialize` function.\n \n ## Examples\n \n \n datetime.to_string(my_datetime)\n // -&gt; &quot;2024-06-21T05:22:22.009534Z&quot; \n \nSynonyms:\ntempo/datetime.to_string\ntempo/datetime to_string","url":"tempo/datetime.html#to_string"},{"doc":"tempo/datetime","title":"to_timezone","content":"pub fn to_timezone(\n  datetime: DateTime,\n  tz: TimeZoneProvider,\n) -&gt; DateTime\n Converts a datetime to the specified timezone. Relies on an external \n package like `gtz` to provide timezone information. Try to prefer using\n `to_local` when converting datetimes to local time, as that does not depend\n on any external package.\n \n ## Example\n \n \n import gtz\n let assert Ok(tz) = gtz.timezone(&quot;America/New_York&quot;)\n datetime.literal(&quot;2024-06-21T06:30:02.334Z&quot;)\n |&gt; datetime.to_timezone(tz)\n |&gt; datetime.to_string\n // -&gt; &quot;2024-01-03T02:30:02.334-04:00&quot;\n \n \n \n import gtz\n let assert Ok(local_tz) = gtz.local_name() |&gt; gtz.timezone\n datetime.from_unix_seconds(1_729_257_776)\n |&gt; datetime.to_timezone(local_tz)\n |&gt; datetime.to_string\n // -&gt; &quot;2024-10-18T14:22:56.000+01:00&quot;\n \nSynonyms:\ntempo/datetime.to_timezone\ntempo/datetime to_timezone","url":"tempo/datetime.html#to_timezone"},{"doc":"tempo/datetime","title":"to_unix_micro","content":"pub fn to_unix_micro(datetime: DateTime) -&gt; Int\n Returns the UTC unix timestamp in microseconds of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-17T13:01:54.334734Z&quot;)\n |&gt; datetime.to_unix_micro\n // -&gt; 1_718_629_314_334_734\n \nSynonyms:\ntempo/datetime.to_unix_micro\ntempo/datetime to_unix_micro","url":"tempo/datetime.html#to_unix_micro"},{"doc":"tempo/datetime","title":"to_unix_milli","content":"pub fn to_unix_milli(datetime: DateTime) -&gt; Int\n Returns the UTC unix timestamp in milliseconds of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-17T13:01:54.334Z&quot;)\n |&gt; datetime.to_unix_milli\n // -&gt; 1_718_629_314_334\n \nSynonyms:\ntempo/datetime.to_unix_milli\ntempo/datetime to_unix_milli","url":"tempo/datetime.html#to_unix_milli"},{"doc":"tempo/datetime","title":"to_unix_seconds","content":"pub fn to_unix_seconds(datetime: DateTime) -&gt; Int\n Returns the UTC unix timestamp of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-17T12:59:51Z&quot;)\n |&gt; datetime.to_unix_seconds\n // -&gt; 1_718_829_191\n \nSynonyms:\ntempo/datetime.to_unix_seconds\ntempo/datetime to_unix_seconds","url":"tempo/datetime.html#to_unix_seconds"},{"doc":"tempo/datetime","title":"to_utc","content":"pub fn to_utc(datetime: DateTime) -&gt; DateTime\n Converts a datetime to the equivalent UTC time.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T05:36:11.195-04:00&quot;)\n |&gt; datetime.to_utc\n // -&gt; datetime.literal(&quot;2024-06-21T09:36:11.195Z&quot;)\n \nSynonyms:\ntempo/datetime.to_utc\ntempo/datetime to_utc","url":"tempo/datetime.html#to_utc"},{"doc":"tempo/datetime","title":"tempo/datetime","content":" Functions to use with the `DateTime` type in Tempo.\n \n ## Examples\n \n ```gleam\n import tempo/datetime\n import snag\n \n pub fn main() {\n   datetime.literal(&quot;2024-12-25T06:00:00+05:00&quot;)\n   |&gt; datetime.format(&quot;ddd @ h:mm A, Z&quot;)\n   // -&gt; &quot;Fri @ 6:00 AM, +05:00&quot;\n \n   datetime.parse(&quot;06:21:2024 23:17:07.123Z&quot;, &quot;MM:DD:YYYY HH:mm:ss.SSSZ&quot;)\n   |&gt; snag.map_error(datetime.describe_parse_error)\n   |&gt; result.map(datetime.to_string)\n   // -&gt; Ok(&quot;2024-06-21T23:17:07.123Z&quot;)\n }\n ```\n \n ```gleam\n import gleam/list\n import tempo/datetime\n import tempo/period\n \n pub fn get_every_friday_between(datetime1, datetime2) {\n   period.new(datetime1, datetime2)\n   |&gt; period.comprising_dates\n   |&gt; list.filter(fn(date) { \n     date |&gt; date.to_day_of_week == date.Fri\n   })\n   // -&gt; [&quot;2024-06-21&quot;, &quot;2024-06-28&quot;, &quot;2024-07-05&quot;]\n }\n ```","url":"tempo/datetime.html"},{"doc":"tempo/instant","title":"as_local_date","content":"pub fn as_local_date(instant: Instant) -&gt; Date\n Converts an instant to a local date value.\n \n ## Example\n \n \n tempo.now()\n |&gt; instant.as_local_date\n // -&gt; date.literal(&quot;2024-12-26&quot;)\n \nSynonyms:\ntempo/instant.as_local_date\ntempo/instant as_local_date","url":"tempo/instant.html#as_local_date"},{"doc":"tempo/instant","title":"as_local_datetime","content":"pub fn as_local_datetime(instant: Instant) -&gt; DateTime\n Converts an instant to a local datetime value. Do not use this with \n `datetime.difference` to time tasks!\n \n ## Example\n \n \n tempo.now()\n |&gt; instant._as_local_datetime\n // -&gt; datetime.literal(&quot;2024-12-26T12:32:34-04:00&quot;)\n \nSynonyms:\ntempo/instant.as_local_datetime\ntempo/instant as_local_datetime","url":"tempo/instant.html#as_local_datetime"},{"doc":"tempo/instant","title":"as_local_time","content":"pub fn as_local_time(instant: Instant) -&gt; Time\n Converts an instant to a local time value.\n \n ## Example\n \n \n tempo.now()\n |&gt; instant.as_local_time\n // -&gt; time.literal(&quot;12:32:34&quot;)\n \nSynonyms:\ntempo/instant.as_local_time\ntempo/instant as_local_time","url":"tempo/instant.html#as_local_time"},{"doc":"tempo/instant","title":"as_utc_date","content":"pub fn as_utc_date(instant: Instant) -&gt; Date\n Converts an instant to a UTC date value.\n \n ## Example\n \n \n tempo.now()\n |&gt; instant.as_utc_date\n // -&gt; date.literal(&quot;2024-12-27&quot;)\n \nSynonyms:\ntempo/instant.as_utc_date\ntempo/instant as_utc_date","url":"tempo/instant.html#as_utc_date"},{"doc":"tempo/instant","title":"as_utc_datetime","content":"pub fn as_utc_datetime(instant: Instant) -&gt; DateTime\n Converts an instant to a UTC datetime value. Do not use this with \n `datetime.difference` to time tasks!\n \n ## Example\n \n \n instant.now()\n |&gt; instant.as_utc_datetime\n // -&gt; datetime.literal(&quot;2024-12-26T16:32:34Z&quot;)\n \nSynonyms:\ntempo/instant.as_utc_datetime\ntempo/instant as_utc_datetime","url":"tempo/instant.html#as_utc_datetime"},{"doc":"tempo/instant","title":"as_utc_time","content":"pub fn as_utc_time(instant: Instant) -&gt; Time\n Converts an instant to a UTC time value.\n \n ## Example\n \n \n tempo.now()\n |&gt; instant.as_utc_time\n // -&gt; time.literal(&quot;16:32:34&quot;)\n \nSynonyms:\ntempo/instant.as_utc_time\ntempo/instant as_utc_time","url":"tempo/instant.html#as_utc_time"},{"doc":"tempo/instant","title":"compare","content":"pub fn compare(a: Instant, b: Instant) -&gt; Order\n Compares two instants.\n \n ## Example\n \n \n let start = tempo.now()\n let end = tempo.now()\n \n instant.compare(start, end)\n // -&gt; order.Lt\n \nSynonyms:\ntempo/instant.compare\ntempo/instant compare","url":"tempo/instant.html#compare"},{"doc":"tempo/instant","title":"difference","content":"pub fn difference(from a: Instant, to b: Instant) -&gt; Duration\n Gets the difference between two instants.\n \n ## Example\n \n \n let start = tempo.now()\n let end = tempo.now()\n \n instant.difference(from: start, to: end)\n // -&gt; duration.microseconds(1)\n \nSynonyms:\ntempo/instant.difference\ntempo/instant difference","url":"tempo/instant.html#difference"},{"doc":"tempo/instant","title":"format_local","content":"pub fn format_local(\n  instant: Instant,\n  in format: DateTimeFormat,\n) -&gt; String\n Formats an instant as a local datetime value.\n \n ## Example\n \n \n tempo.now()\n |&gt; instant.format_local(tempo.ISO8601Micro)\n // -&gt; &quot;2024-12-26T12:32:34.534223-04:00&quot;\n \nSynonyms:\ntempo/instant.format_local\ntempo/instant format_local","url":"tempo/instant.html#format_local"},{"doc":"tempo/instant","title":"format_since","content":"pub fn format_since(start start: Instant) -&gt; String\n Formats the duration between the current system time and the provided \n instant.\n \n ## Example\n \n \n let monotonic_timer = instant.now()\n // Do long task ...\n instant.format_since(monotonic_timer)\n // -&gt; &quot;42 minutes&quot;\nSynonyms:\ntempo/instant.format_since\ntempo/instant format_since","url":"tempo/instant.html#format_since"},{"doc":"tempo/instant","title":"format_utc","content":"pub fn format_utc(\n  instant: Instant,\n  in format: DateTimeFormat,\n) -&gt; String\n Formats an instant as a UTC datetime value.\n \n ## Example\n \n \n tempo.now()\n |&gt; instant.format_utc(tempo.ISO8601Milli)\n // -&gt; &quot;2024-12-26T16:32:34.254Z&quot;\n \nSynonyms:\ntempo/instant.format_utc\ntempo/instant format_utc","url":"tempo/instant.html#format_utc"},{"doc":"tempo/instant","title":"is_earlier","content":"pub fn is_earlier(a: Instant, than b: Instant) -&gt; Bool\n Checks if the first instant is earlier than the second instant.\n \n ## Example\n \n \n let start = tempo.now()\n let end = tempo.now()\n \n instant.is_earlier(start, than: end)\n // -&gt; True\n \nSynonyms:\ntempo/instant.is_earlier\ntempo/instant is_earlier","url":"tempo/instant.html#is_earlier"},{"doc":"tempo/instant","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(a: Instant, to b: Instant) -&gt; Bool\n Checks if the first instant is earlier or equal to the second instant.\n \n ## Example\n \n \n let start = tempo.now()\n let end = tempo.now()\n \n instant.is_earlier_or_equal(start, to: end)\n // -&gt; True\n \nSynonyms:\ntempo/instant.is_earlier_or_equal\ntempo/instant is_earlier_or_equal","url":"tempo/instant.html#is_earlier_or_equal"},{"doc":"tempo/instant","title":"is_equal","content":"pub fn is_equal(a: Instant, to b: Instant) -&gt; Bool\n Checks if the first instant is equal to the second instant.\n \n ## Example\n \n \n let start = tempo.now()\n let end = tempo.now()\n \n instant.is_equal(start, to: end)\n // -&gt; False\n \nSynonyms:\ntempo/instant.is_equal\ntempo/instant is_equal","url":"tempo/instant.html#is_equal"},{"doc":"tempo/instant","title":"is_later","content":"pub fn is_later(a: Instant, than b: Instant) -&gt; Bool\n Checks if the first instant is later than the second instant.\n \n ## Example\n \n \n let start = tempo.now()\n let end = tempo.now()\n \n instant.is_later(start, than: end)\n // -&gt; False\n \nSynonyms:\ntempo/instant.is_later\ntempo/instant is_later","url":"tempo/instant.html#is_later"},{"doc":"tempo/instant","title":"is_later_or_equal","content":"pub fn is_later_or_equal(a: Instant, to b: Instant) -&gt; Bool\n Checks if the first instant is later or equal to the second instant.\n \n ## Example\n \n \n let start = tempo.now()\n let end = tempo.now()\n \n instant.is_later_or_equal(start, to: end)\n // -&gt; False\n \nSynonyms:\ntempo/instant.is_later_or_equal\ntempo/instant is_later_or_equal","url":"tempo/instant.html#is_later_or_equal"},{"doc":"tempo/instant","title":"now","content":"pub fn now() -&gt; Instant\n The current instant on the host system.\nSynonyms:\ntempo/instant.now\ntempo/instant now","url":"tempo/instant.html#now"},{"doc":"tempo/instant","title":"since","content":"pub fn since(start start: Instant) -&gt; Duration\n Gets the duration between the current system time and the provided instant.\n \n ## Example\n \n \n let monotonic_timer = instant.now()\n // Do long task ...\n instant.since(monotonic_timer)\n // -&gt; duration.minutes(42)\nSynonyms:\ntempo/instant.since\ntempo/instant since","url":"tempo/instant.html#since"},{"doc":"tempo/instant","title":"tempo/instant","content":" The `Instant` type is the most complete representation of system time. It is\n a monotonic type that represents a unique point in time on the host system.\n It is the only way to get the current time on the host system as a value, \n and means very little on other systems. Try to keep `Instant` values as\n this type as long as possible in your programs. It can be safely used for \n timing tasks, sorting times, and recording times.\n \n If you would like to send this value outside of Gleam, it will have \n to be converted to a `DateTime` value first.\n \n ## Timing Tasks\n \n ```gleam\n import tempo/instant\n \n pub fn main() {\n   let monotonic_timer = instant.now()\n   // Do long task ...\n   instant.since(monotonic_timer)\n   // -&gt; duration.minutes(42)\n \n   instant.format_since(monotonic_timer)\n   // -&gt; &quot;42 minutes&quot;\n }\n ```\n \n ## Sorting Times\n \n ```gleam\n import tempo/instant\n \n pub fn main() {\n   let completed_async_tasks = // ...\n \n   let task_by_completion_time = \n     list.sort(\n       completed_async_tasks,\n       fn(a, b) { instant.compare(a.completion_time, b.completion_time) },\n     )\n }\n ```\n \n ## Recording Times\n\n ```gleam\n import tempo/instant\n \n pub type Record {\n   Record(name: String, created_time: instant.Instant)\n }\n \n pub fn new_record(name) {\n   Record(name: name, created_time: instant.now())\n }\n \n pub fn render_record_created_time(record: Record) {\n   instant.format(record.created_time, tempo.ISO8601Milli)\n }\n ```","url":"tempo/instant.html"},{"doc":"tempo/month_year","title":"compare","content":"pub fn compare(a: MonthYear, to b: MonthYear) -&gt; Order\n\nSynonyms:\ntempo/month_year.compare\ntempo/month_year compare","url":"tempo/month_year.html#compare"},{"doc":"tempo/month_year","title":"days_of","content":"pub fn days_of(my: MonthYear) -&gt; Int\n\nSynonyms:\ntempo/month_year.days_of\ntempo/month_year days_of","url":"tempo/month_year.html#days_of"},{"doc":"tempo/month_year","title":"next","content":"pub fn next(month: MonthYear) -&gt; MonthYear\n Returns the next month in the civil calendar.\n \n ## Example\n \n \n tempo.MonthYear(tempo.Jan, 2024)\n |&gt; month_year.next\n // -&gt; tempo.MonthYear(tempo.Feb, 2024)\n \n \n \n tempo.MonthYear(tempo.Dec, 2024)\n |&gt; month_year.next\n // -&gt; tempo.MonthYear(tempo.Jan, 2025)\n \nSynonyms:\ntempo/month_year.next\ntempo/month_year next","url":"tempo/month_year.html#next"},{"doc":"tempo/month_year","title":"prior","content":"pub fn prior(my: MonthYear) -&gt; MonthYear\n Returns the previous month in the civil calendar.\n \n ## Example\n \n \n tempo.MonthYear(tempo.Jan, 2024)\n |&gt; month_year.prior\n // -&gt; tempo.MonthYear(tempo.Dec, 2023)\n \n \n \n tempo.MonthYear(tempo.Feb, 2024)\n |&gt; month_year.prior\n // -&gt; tempo.MonthYear(tempo.Jan, 2024)\n \nSynonyms:\ntempo/month_year.prior\ntempo/month_year prior","url":"tempo/month_year.html#prior"},{"doc":"tempo/month_year","title":"to_int","content":"pub fn to_int(my: MonthYear) -&gt; Int\n\nSynonyms:\ntempo/month_year.to_int\ntempo/month_year to_int","url":"tempo/month_year.html#to_int"},{"doc":"tempo/month_year","title":"tempo/month_year","content":"","url":"tempo/month_year.html"},{"doc":"tempo/period","title":"Unit","content":"pub type Unit {\n  Year\n  Month\n  Week\n  Day\n  Hour\n  Minute\n  Second\n  Millisecond\n  Microsecond\n}\n\nYear\n\n\nMonth\n\n\nWeek\n\n\nDay\n\n\nHour\n\n\nMinute\n\n\nSecond\n\n\nMillisecond\n\n\nMicrosecond\n\n\nSynonyms:\ntempo/period.Unit\ntempo/period Unit","url":"tempo/period.html#Unit"},{"doc":"tempo/period","title":"as_days","content":"pub fn as_days(period: Period) -&gt; Int\n Returns the number of days in the period.\n \n ## Examples\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_days\n // -&gt; 7\n \nSynonyms:\ntempo/period.as_days\ntempo/period as_days","url":"tempo/period.html#as_days"},{"doc":"tempo/period","title":"as_days_fractional","content":"pub fn as_days_fractional(period: Period) -&gt; Float\n Returns the number of days in the period.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_days_fractional\n // -&gt; 7.645277777777778\n \nSynonyms:\ntempo/period.as_days_fractional\ntempo/period as_days_fractional","url":"tempo/period.html#as_days_fractional"},{"doc":"tempo/period","title":"as_duration","content":"pub fn as_duration(period: Period) -&gt; Duration\n Returns a period as a duration, losing the context of the start and end \n datetimes.\n \n ## Example\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_duration\n |&gt; duration.as_weeks\n // -&gt; 1\n \nSynonyms:\ntempo/period.as_duration\ntempo/period as_duration","url":"tempo/period.html#as_duration"},{"doc":"tempo/period","title":"as_seconds","content":"pub fn as_seconds(period: Period) -&gt; Int\n Returns the number of seconds in the period.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T07:16:32&quot;),\n   end: naive_datetime.literal(&quot;2024-06-13T07:16:12&quot;),\n )\n |&gt; period.as_seconds\n // -&gt; 20\n \nSynonyms:\ntempo/period.as_seconds\ntempo/period as_seconds","url":"tempo/period.html#as_seconds"},{"doc":"tempo/period","title":"comprising_dates","content":"pub fn comprising_dates(period: Period) -&gt; List(Date)\n Returns a list over all the dates in the period, inclusive of the \n dates of both the start and end datetimes and ignoring the offset.\n\n ## Examples\n \n \n period.new_naive(\n   start: naive_datetime.literal(&quot;2024-06-19T23:59:59-04:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T00:16:12+01:00&quot;),\n )\n |&gt; period.comprising_dates\n // -&gt; [\n //   date.literal(&quot;2024-06-19&quot;),\n //   date.literal(&quot;2024-06-20&quot;),\n //   date.literal(&quot;2024-06-21&quot;),\n // ]\n \n \n \n period.from_month(tempo.Feb, 2024)\n |&gt; period.comprising_dates\n // -&gt; [\n //   date.literal(&quot;2024-02-01&quot;),\n //   ...\n //   date.literal(&quot;2024-02-29&quot;),\n // ]\nSynonyms:\ntempo/period.comprising_dates\ntempo/period comprising_dates","url":"tempo/period.html#comprising_dates"},{"doc":"tempo/period","title":"comprising_months","content":"pub fn comprising_months(period: Period) -&gt; List(MonthYear)\n Returns list over all the months in the period, inclusive of the\n months of both the start and end datetimes and ignoring the offset.\n\n ## Examples\n \n \n period.new(\n   start: datetime.literal(&quot;2024-10-25T00:47:00-04:00&quot;),\n   end: datetime.literal(&quot;2025-04-30T23:59:59-04:00&quot;),\n )\n |&gt; period.comprising_months\n // -&gt; [\n //   tempo.MonthYear(tempo.Oct, 2024),\n //   tempo.MonthYear(tempo.Nov, 2024),\n //   tempo.MonthYear(tempo.Dec, 2024),\n //   tempo.MonthYear(tempo.Jan, 2025),\n //   tempo.MonthYear(tempo.Feb, 2025),\n //   tempo.MonthYear(tempo.Mar, 2025),\n //   tempo.MonthYear(tempo.Apr, 2025),\n // ]\n \nSynonyms:\ntempo/period.comprising_months\ntempo/period comprising_months","url":"tempo/period.html#comprising_months"},{"doc":"tempo/period","title":"contains_date","content":"pub fn contains_date(period: Period, date: Date) -&gt; Bool\n Checks if a date is contained within a period, inclusive of the start and\n end datetimes.\n \n ## Examples\n \n \n period.from_month(tempo.Jun, 2024)\n |&gt; period.contains_date(date.literal(&quot;2024-06-30&quot;))\n // -&gt; True\n \n \n \n period.from_month(tempo.Jun, 2024)\n |&gt; period.contains_date(date.literal(&quot;2024-07-22&quot;))\n // -&gt; False\n \n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-21&quot;))\n |&gt; period.contains_date(date.literal(&quot;2024-06-21&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-21&quot;))\n |&gt; period.contains_date(date.literal(&quot;2024-06-27&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/period.contains_date\ntempo/period contains_date","url":"tempo/period.html#contains_date"},{"doc":"tempo/period","title":"contains_datetime","content":"pub fn contains_datetime(\n  period: Period,\n  datetime: DateTime,\n) -&gt; Bool\n Checks if a datetime is contained within a period, inclusive of the\n start and end datetimes.\n \n ## Examples\n \n \n period.from_month(tempo.Jun, 2024)\n |&gt; period.contains_datetime(\n   datetime.literal(&quot;2024-06-30T24:00:00-07:00&quot;),\n )\n // -&gt; True\n \n \n \n datetime.as_period(\n   start: datetime.literal(&quot;2024-06-13T15:47:00+06:00&quot;),\n   end: datetime.literal(&quot;2024-06-21T07:16:12+06:00&quot;),\n )\n |&gt; period.contains_datetime(\n   datetime.literal(&quot;2024-06-20T07:16:12+06:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/period.contains_datetime\ntempo/period contains_datetime","url":"tempo/period.html#contains_datetime"},{"doc":"tempo/period","title":"contains_naive_datetime","content":"pub fn contains_naive_datetime(\n  period: Period,\n  naive_datetime: NaiveDateTime,\n) -&gt; Bool\n Checks if a naive datetime is contained within a period, inclusive of the\n start and end datetimes.\n \n ## Examples\n \n \n period.from_month(tempo.Jun, 2024)\n |&gt; period.contains_naive_datetime(\n   naive_datetime.literal(&quot;2024-06-30T24:00:00&quot;),\n )\n // -&gt; True\n \n \n \n period.from_month(tempo.Jun, 2024)\n |&gt; period.contains_naive_datetime(\n   naive_datetime.literal(&quot;2024-07-22T24:00:00&quot;),\n )\n // -&gt; False\n \n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-21&quot;))\n |&gt; period.contains_naive_datetime(\n   naive_datetime.literal(&quot;2024-06-21T13:50:00&quot;),\n )\n // -&gt; False\n \n \n \n date.as_period(\n   start: date.literal(&quot;2024-06-13&quot;),\n   end: date.literal(&quot;2024-06-21&quot;),\n )\n |&gt; period.contains_naive_datetime(\n   naive_datetime.literal(&quot;2024-06-21T13:50:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/period.contains_naive_datetime\ntempo/period contains_naive_datetime","url":"tempo/period.html#contains_naive_datetime"},{"doc":"tempo/period","title":"from_dates","content":"pub fn from_dates(start start: Date, end end: Date) -&gt; Period\n Creates a new period from the start and end dates.\n \n ## Examples\n \n \n period.from_dates(\n   start: date.literal(&quot;2024-06-13&quot;),\n   end: date.literal(&quot;2024-06-21&quot;),\n )\n |&gt; period.as_days\n // -&gt; 7\n \nSynonyms:\ntempo/period.from_dates\ntempo/period from_dates","url":"tempo/period.html#from_dates"},{"doc":"tempo/period","title":"from_datetimes","content":"pub fn from_datetimes(\n  start start: DateTime,\n  end end: DateTime,\n) -&gt; Period\n Creates a new period from the start and end datetimes.\n \n ## Examples\n \n \n period.from_datetimes(\n   start: datetime.literal(&quot;2024-06-13T15:47:00+06:00&quot;),\n   end: datetime.literal(&quot;2024-06-21T07:16:12+06:00&quot;),\n )\n |&gt; period.as_days\n // -&gt; 7\n \nSynonyms:\ntempo/period.from_datetimes\ntempo/period from_datetimes","url":"tempo/period.html#from_datetimes"},{"doc":"tempo/period","title":"from_month","content":"pub fn from_month(my: MonthYear) -&gt; Period\n Creates a period of the specified month year, starting at 00:00:00 on the\n first day of the month and ending at 24:00:00 on the last day of the month.\n \n \n ## Examples\n \n \n period.from_month(tempo.MonthYear(tempo.Feb, 2024))\n |&gt; period.contains_date(date.literal(&quot;2024-06-21&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/period.from_month\ntempo/period from_month","url":"tempo/period.html#from_month"},{"doc":"tempo/period","title":"from_naive_datetimes","content":"pub fn from_naive_datetimes(\n  start start: NaiveDateTime,\n  end end: NaiveDateTime,\n) -&gt; Period\n Creates a new period from the start and end naive datetimes.\n \n ## Examples\n \n \n period.from_naive_datetimes(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_days\n // -&gt; 7\n \nSynonyms:\ntempo/period.from_naive_datetimes\ntempo/period from_naive_datetimes","url":"tempo/period.html#from_naive_datetimes"},{"doc":"tempo/period","title":"new","content":"pub fn new(start start: DateTime, end end: DateTime) -&gt; Period\n\nSynonyms:\ntempo/period.new\ntempo/period new","url":"tempo/period.html#new"},{"doc":"tempo/period","title":"new_naive","content":"pub fn new_naive(\n  start start: NaiveDateTime,\n  end end: NaiveDateTime,\n) -&gt; Period\n\nSynonyms:\ntempo/period.new_naive\ntempo/period new_naive","url":"tempo/period.html#new_naive"},{"doc":"tempo/period","title":"tempo/period","content":" Functions to use with the `Period` type in Tempo. Periods represent a \n positive range of dates or datetimes.\n \n ## Example\n \n ```gleam\n import tempo/period\n import tempo/date\n \n pub fn get_days_between(datetime1, datetime2) {\n   period.from_datetimes(start: datetime1, end: datetime2)\n   |&gt; period.as_days\n   // -&gt; 11\n }\n ```\n \n ```gleam\n import tempo/period\n import tempo/date\n \n pub fn get_every_friday_between(date1, date2) {\n   period.from_days(date1, date2)\n   |&gt; period.comprising_dates\n   |&gt; list.filter(fn(date) { \n     date.to_day_of_week(date) == date.Fri\n   })\n   // -&gt; [&quot;2024-06-21&quot;, &quot;2024-06-28&quot;, &quot;2024-07-05&quot;]\n }\n ```","url":"tempo/period.html"},{"doc":"tempo/year","title":"days","content":"pub fn days(of year: Int) -&gt; Int\n Get the number of days in a year. Accounts for leap years.\n \n ## Examples\n \n \n year.days(2024)\n // -&gt; 366\n \n \n \n year.days(2025)\n // -&gt; 365\n \nSynonyms:\ntempo/year.days\ntempo/year days","url":"tempo/year.html#days"},{"doc":"tempo/year","title":"is_leap_year","content":"pub fn is_leap_year(year: Int) -&gt; Bool\n Checks if a year is a leap year.\n \n ## Examples\n \n \n year.is_leap_year(2024)\n // -&gt; True\n \n \n \n year.is_leap_year(2025)\n // -&gt; False\n \nSynonyms:\ntempo/year.is_leap_year\ntempo/year is_leap_year","url":"tempo/year.html#is_leap_year"},{"doc":"tempo/year","title":"tempo/year","content":" Functions to use with the `Year` type in Tempo. Years are pretty simple\n thankfully.","url":"tempo/year.html"}]);